function pm = price_pm(w,pmguess)
global N alpha eta theta beta K omega OM L lambda A B KOM;

% price_pm.m 	March 20, 2004
%   pm = price_pm(w,pguess)
% This function calculates the vector pm defined in (3.8) 
% given the input wage vector w. Input w is an nx1 column vector. 
% uses the global variables defined in inputs.m
% pmguess is an initial guess of pm

% Iterative Solution for pp = pc.^(-1/theta)

% pm = A*(KOM*w.^(-1/theta).*lambda).^(-theta);  Old initial guess

pmlow = (A*B)^(1/beta) * (( sum( w.^(-beta/theta) .*lambda ) ).^(-theta/beta)); % New new initial guess
pmhigh = pmlow / ( (min(min(K.*OM)))^(1/beta) ) ;
pm = min( max( ones(N,1)*pmlow,  pmguess ) , ones(N,1)*pmhigh )  ; 

% Initial price
pp = pm.^(-1/theta);
tolpp=1;
iter=0;
toler = 1.e-40;
%%%%%% Note %%%%%%%
% toler very low, say 1e-40 is required for theta small, say 0.05 and w or lambda very unequal

while (tolpp>toler)&(iter<400) % stop when the tolerance is small enough, 
                                % or when was running for more than 200 iterations.
    part1 = ((w.^beta).^(-1/theta).*pp.^(1-beta).*lambda)';
    together = (A*B)^(-1/theta).*KOM.*kron(ones(N,1), part1);   
    ppp = sum(together,2);
    tolpp = max(abs(ppp-pp));
    pp = ppp;
    iter=iter+1;
end
% display the tolerance and the number of iterations after which
% convergence is reached:
% disp('    tolpp    iter')
% disp([tolpp iter])
pm = pp.^(-theta); % gives the price vector pc given the wage vector w.