% Feb 28 2006
%
% This file produces figures 7.1-7.2
% It calibrates L=lambda to the world distribution of GDP for 3 different thetas
% 
% It requires to have the programs:
%       phiL.m, Z.m. T.m, price_pm.m, eqT.m, findL.m, inputs.m, outputeq.m, outputcal2.m, dataload.
% and the data:
%       gdppercapitadata.m, countrycodes.m and datatrade.m

clear all;

% Step 1: set the inputs
inputs ;        

% Step 2: load the data
dataload ;

close all; % close graphs created by dataload

shareGDPcal = shareGDPdata;

% checking  DELETE AFTER CHECK
%shareGDPcal = exp(logspace(-8,-1,60)');


shareGDPcal = shareGDPcal/sum(shareGDPcal);

thetavec = [0.1, 0.15, 0.25];

vmodel = ones(N,3);
wmodel = vmodel;

for ii=1:3;   
    
    theta = thetavec(ii);
   
    for jj = 1 : N;
        
        n = 1/shareGDPcal(jj);  % 
                
        % vsym :  import to GDP ratio for synmmetric model with n equal countries
        inter = omega + 1 /( (n-1)*(kappa*omega)^(1/theta) ) ;
        vsym(jj,ii) = (1-alpha) / ( 1 - omega + beta*inter ); 

    end ;
    
    KOM  = (K.*OM).^(1/theta); %  adust vector correspondingly
    
    % Step 3: run the program to calibrate lambda = L: obtain v and w
    outputcal2;

    close all;  % close all the graphs generated by outputcal2.m
    
    %store volume of trade and wages of the corresponding theta;
    vmodel(:,ii) = v;
    wmodel(:,ii) = w;
    
end


figure(1) 
plot(log(shareGDPcal),log(wmodel(:,1)),log(shareGDPcal),log(wmodel(:,2)),log(shareGDPcal),log(wmodel(:,3)))
title({'FIGURE 7.1: WAGES VERSUS SIZE', 'Three values of \theta '})
xlabel('COUNTRY SIZE: log share of GDP')
ylabel('WAGES in logs')
grid on;
yl=min(min(log(wmodel)));
yh=max(max(log(wmodel)));
axis([log(0.0005), log(0.3), yl*0.99 yh*1.01]);
text(log(0.12),yl+0.5*(yh-yl),'Parameters');
text(log(0.12),yl+0.425*(yh-yl),['\alpha = ',num2str(alpha)]);
text(log(0.12),yl+0.35*(yh-yl),['\beta = ',num2str(beta)]);
text(log(0.12),yl+0.275*(yh-yl),['\kappa = ',num2str(kappa)]);
text(log(0.12),yl+0.2*(yh-yl),['\omega = ',num2str(omega)]);

j=56; 
for i=1:3;
    text(log(shareGDPcal(j+i)),log(wmodel(j+i,i))+0.02,['\theta = ',num2str(thetavec(i))])
end



figure(2)
% use jjth component of the thetavec vector
jj=2;
plot(log(shareGDPdata),vdata,'ko',log(shareGDPcal),vmodel(:,jj),log(shareGDPcal),vsym(:,jj))
title('FIGURE 7.2: VOLUME OF TRADE')
ylabel('IMPORT TO GDP RATIO')
xlabel('COUNTRY SIZE: log of share of GDP');
grid;
dx = max(max(log(shareGDPdata))) - min(min(log(shareGDPdata))) ;
xlow = min(min(log(shareGDPdata)));
dy = 0.75;
ylow = 0;
axis([log(0.001), log(0.35), ylow, ylow+dy])
text( xlow+.875*dx, ylow+dy*.575, ['\theta = ', num2str(thetavec(jj))]);
text( xlow+.875*dx, ylow+dy*.65, ['\omega = ', num2str(omega)]);
text( xlow+.875*dx, ylow+dy*.725, ['\kappa = ', num2str(kappa)]);
text( xlow+.875*dx, ylow+dy*.8, ['\beta = ', num2str(beta)]);
text( xlow+.875*dx, ylow+dy*.875, ['\alpha = ', num2str(alpha)]);
text( xlow+.875*dx, ylow+dy*.95, 'Parameters ');

text(log(shareGDPcal(2))-.2, vmodel(2,jj)+.03,'CALIBRATED' )
text(log(shareGDPcal(2))-0.9, vsym(2,jj), 'SYMMETRIC')

i = 1;
text(log(shareGDPdata(i))+0.05,vdata(i),'USA')
i = 2;
text(log(shareGDPdata(i))+0.03,vdata(i)-0.015,'Japan')
i = 17;
text(log(shareGDPdata(i))+0.1,vdata(i),'Argentina')
i = 20;
text(log(shareGDPdata(i))+0.1,vdata(i),'Sweden')
i = 19;
text(log(shareGDPdata(i))+0.1,vdata(i),'Belgium')
i = 3;
text(log(shareGDPdata(i))+0.1,vdata(i),'Germany')
i = 15;
text(log(shareGDPdata(i))+0.1,vdata(i),'Netherlands')
i = 46 ;
text(log(shareGDPdata(i))+0.1,vdata(i),'Peru')
i= 47 ;
text(log(shareGDPdata(i))+0.1,vdata(i),'Czech Republic')
i = 51;
text(log(shareGDPdata(i))+0.1,vdata(i)-0.01,'Bangladesh')
i = 9;
text(log(shareGDPdata(i))+0.1,vdata(i),'Brazil')
i = 10;
text(log(shareGDPdata(i))+0.1,vdata(i),'Canada')



figure(3)
plot(log(shareGDPdata),vdata,'k*',log(shareGDPcal),vmodel(:,1),log(shareGDPcal),vmodel(:,2),log(shareGDPcal),vmodel(:,3))
title({'OLD FIGURE 7.2: VOLUME OF TRADE, Data: *,  Model: solid lines ', ' L=lambda calibrated to share of GDP', 'Three values of \theta' })
ylabel('Import to GDP ratio v')
xlabel('country size, log of fraction of world GDP');
grid;
dx = max(max(log(shareGDPdata))) - min(min(log(shareGDPdata))) ;
xlow = min(min(log(shareGDPdata)));
dy = max(max(vdata)) - min(min(vdata)) ;
ylow = min(min(vdata));
text( xlow+.875*dx, ylow+dy*.75, ['\omega = ', num2str(omega)]);
text( xlow+.875*dx, ylow+dy*.8, ['\alpha = ', num2str(alpha)]);
text( xlow+.875*dx, ylow+dy*.85, ['\beta = ', num2str(beta)]);
text( xlow+.875*dx, ylow+dy*.9, ['\kappa = ', num2str(kappa)]);
text( xlow+.875*dx, ylow+dy*.95, 'Parameters ');

j=2; 
for i=1:3;
    text(log(shareGDPcal(j)-0.02),vmodel(j,i)+0.02,['\theta = ',num2str(thetavec(i))])
end
 
% Singapore i = 39;
i=39;
text(log(shareGDPdata(i))+0.05,vdata(i),'Singapore')
% Hong Kong i = 25
i=25;
text(log(shareGDPdata(i))+0.05,vdata(i),'Hong Kong')
% Malaysia i = 38
i = 38;
text(log(shareGDPdata(i))+0.05,vdata(i),'Malaysia')
i = 1;
text(log(shareGDPdata(i))+0.03,vdata(i),'USA')
i = 2;
text(log(shareGDPdata(i))+0.03,vdata(i)-0.02,'Japan')
i = 17;
text(log(shareGDPdata(i))+0.05,vdata(i),'Argentina')
i = 20;
text(log(shareGDPdata(i))+0.05,vdata(i),'Sweden')
i = 19;
text(log(shareGDPdata(i))+0.05,vdata(i),'Belgium')
i = 50;
text(log(shareGDPdata(i))+0.05,vdata(i),'Ukraine')
i = 51;
%text(log(shareGDPdata(i))+0.05,vdata(i),'Bangladesh')
i = 3;
text(log(shareGDPdata(i))+0.04,vdata(i)-0.02,'Germany')
i = 15;
text(log(shareGDPdata(i))+0.05,vdata(i),'Netherlands')
i = 46 ;
text(log(shareGDPdata(i))+0.05,vdata(i),'Peru')
i= 47 ;
text(log(shareGDPdata(i))+0.05,vdata(i),'Czech Republic')
i = 10;
text(log(shareGDPdata(i))+0.05,vdata(i),'Canada')
i = 9;
text(log(shareGDPdata(i))+0.05,vdata(i),'Brazil')
