% March 24, 2004, revised March 2006
%
% This file calibrates L and lambda to the world data set
% using the world distribution of GDP, and the world distribution or
% relative prices of investment to consumption
% It requires to have the programs:
%       phi.m, Z.m. T.m, price_pm.m, eqT.m, findLandl.m, inputs.m, outputeq.m, outputcal.m, dataload.
% and the data:
%       gdppercapitadata.m, countrycodes.m and datatrade.m

clear all;

% Step 1: set the inputs
inputs ;        

% Step 2: load the data
dataload ;

close all; % close graphs created by dataload
% set the values to be calibrated from the data
Pcal = pmachtocons .^ (-1);
Pcal = Pcal / sum(Pcal);
shareGDPcal = shareGDPdata;
shareGDPcal = shareGDPcal/sum(shareGDPcal);

% assigns omegas OM using data on tariffs
for i=1:N
%    OM(i,1:N) = 1 - .5*(tariffwto(i)+tariffwb(i))/100;
    OM(i,1:N) = 1 - tariffwto(i)/100;
    OM(i,i) = 1;
end;
KOM  = (K.*OM).^(1/theta); %

% Step 3: run the program to calibrate lambda and L:
outputcal1;


figure(8) 
plot(log(shareGDPcal),vdata,'b*',log(shareGDPcal),v,'ko')
title({'TRADE VS SIZE IN THE MODEL (o) AND IN THE DATA (*)','For L and lambda calibrated to GDP and Relative prices'})
xlabel('Log of Share of GDP in the world')
ylabel('Imports to GDP ratio')
grid on;
axis([log(0.002),log(0.3),0,0.6])
text(log(0.2),0.425,'Parameters');
text(log(0.2),0.4,['\alpha = ',num2str(alpha)]);
text(log(0.2),0.375,['\beta = ',num2str(beta)]);
text(log(0.2),0.35,['\theta = ',num2str(theta)]);
text(log(0.2),0.325,['\kappa = ',num2str(kappa)]);
text(log(0.2),0.3,['\omega = ',num2str(omega)]);


figure(9) 
plot(log(shareGDPcal),w,'b*')
title({'WAGES VS SIZE','For L and lambda calibrated to GDP and Relative prices'})
xlabel('Log of Share of GDP in the world')
ylabel('wages w')
grid on;
yl=min(w);
yh=max(w);
text(log(0.2),yl+0.95*(yh-yl),'Parameters');
text(log(0.2),yl+0.9*(yh-yl),['\alpha = ',num2str(alpha)]);
text(log(0.2),yl+0.85*(yh-yl),['\beta = ',num2str(beta)]);
text(log(0.2),yl+0.8*(yh-yl),['\theta = ',num2str(theta)]);
text(log(0.2),yl+0.75*(yh-yl),['\kappa = ',num2str(kappa)]);
text(log(0.2),yl+0.7*(yh-yl),['\omega = ',num2str(omega)]);

