% March 25, 2004, revised March 2006
%
% This file calibrates L=lambda to the world distribution of GDP
% It requires to have the programs:
%       phiL.m, Z.m. T.m, price_pm.m, eqT.m, findL.m, inputs.m, outputeq.m, outputcal2.m, dataload.
% and the data:
%       gdppercapitadata.m, countrycodes.m and datatrade.m

clear all;

% Step 1: set the inputs
inputs ;        

% Step 2: load the data
dataload ;

close all; % close graphs created by dataload

shareGDPcal = shareGDPdata;
shareGDPcal = shareGDPcal/sum(shareGDPcal);

% assigns values to matrix OM of tariffs using data
for i=1:N
    %OM(i,1:N) = 1 - .5*(tariffwb(i)+tariffwto(i))/100;
    OM(i,1:N) = 1 - tariffwto(i)/100;
    OM(i,i) = 1;
end;
KOM  = (K.*OM).^(1/theta); %

% Step 3: run the program to calibrate lambda = L:
outputcal2;

a = ones(1,1);
clear a;

figure(8) 
plot(log(shareGDPcal),vdata,'b*',log(shareGDPcal),v,'ko')
title({'FIGURE 10.1 TRADE VS SIZE IN THE MODEL (o) AND IN THE DATA (*)','Using estimated tariff factors \omega_i from Table 2 ','For L = lambda calibrated to GDP'})
xlabel('Log of Share of GDP in the world')
ylabel('Imports to GDP ratio')
grid on;
axis([log(0.002),log(0.3),0,0.6])
text(log(0.15),0.425,'Parameters');
text(log(0.15),0.4,['\alpha = ',num2str(alpha)]);
text(log(0.15),0.375,['\beta = ',num2str(beta)]);
text(log(0.15),0.35,['\theta = ',num2str(theta)]);
text(log(0.15),0.325,['\kappa = ',num2str(kappa)]);

a=corrcoef(log(v),log(vdata));
text(log(0.03),0.51,['\rho (log v_d_a_t_a , log v_m_o_d_e_l ) = ', num2str(a(1,2),2)]);


figure(9) 
plot(log(shareGDPcal),log(w),'b*')
title({'WAGES VS SIZE','Using estimated tariff factors \omega_i from Table 2 ','For L = lambda calibrated to GDP'})
xlabel('Log of Share of GDP in the world')
ylabel('wages w')
grid on;
yl=min(w);
yh=max(w);
text(log(0.15),yl+0.75*(yh-yl),'Parameters');
text(log(0.15),yl+0.7*(yh-yl),['\alpha = ',num2str(alpha)]);
text(log(0.15),yl+0.65*(yh-yl),['\beta = ',num2str(beta)]);
text(log(0.15),yl+0.6*(yh-yl),['\theta = ',num2str(theta)]);
text(log(0.15),yl+0.55*(yh-yl),['\kappa = ',num2str(kappa)]);


