% February 28, 2006
%
% This file calibrates L=lambda to the world distribution of GDP
% It requires to have the programs:
%       phiL.m, Z.m. T.m, price_pm.m, eqT.m, findL.m, inputs.m, outputeq.m, outputcal2.m, dataload.
% and the data:
%       gdppercapitadata.m, countrycodes.m and datatrade.m
% this file creates figure 7.3

clear all;

% Step 1: set the inputs
inputs ;        

% Step 2: load the data
dataload ;

close all; % close graphs created by dataload

shareGDPcal = shareGDPdata;
shareGDPcal = shareGDPcal/sum(shareGDPcal);


% Model with tariff from the data
    
    % assigns values to matrix OM of tariffs using data
    for i=1:N
        %OM(i,1:N) = 1 - .5*(tariffwb(i)+tariffwto(i))/100;
        OM(i,1:N) = 1 - tariffwto(i)/100;
        OM(i,i) = 1;
    end;
    KOM  = (K.*OM).^(1/theta); %

    % Step 3: run the program to calibrate lambda = L:
    outputcal2;

    % store relevant info
    v1 = v;
    w1 = w;


% Model with uniform tariffs
    
    % avgtar = mean(tariffwto/100); set tariff equal to average in data
    avgtar = .1;  % set 10% tariff
    omega = 1-avgtar;
    OM = ones(N,N)*omega;
    for i=1:N
        OM(i,i) = 1;
    end;
    KOM  = (K.*OM).^(1/theta); %

    % Step 3: run the program to calibrate lambda = L:
    outputcal2;

    % store relevant info
    v2 = v;
    w2 = w;
   
    
a = ones(1,1);
clear a;

close all;

figure(1) 
plot(log(shareGDPcal),vdata,'bo',log(shareGDPcal),v2,log(shareGDPcal),v1,'k*')
title({'FIGURE 7.3 VOLUME VERSUS SIZE', 'Data (o),  Model w/uniform tariffs (solid),  Model w/tariffs from Table 2 (*)'})
xlabel({'COUNTRY SIZE: log of share of GDP','Correlations for countries with trade volume < 0.75'})
ylabel('IMPORTS TO GDP RATIO')
grid on;
axis([log(0.002),log(0.3),0,0.75])
text(log(0.13),0.5,'Parameters');
text(log(0.13),0.45,['\alpha = ',num2str(alpha)]);
text(log(0.13),0.4,['\beta = ',num2str(beta)]);
text(log(0.13),0.35,['\kappa = ',num2str(kappa)]);
text(log(0.13),0.3,['\omega_u_n_i_f_o_r_m = ',num2str(omega,2)]);
text(log(0.13),0.25,['\theta = ',num2str(theta)]);

a=corrcoef(log(v1(vdata<0.75)),log(vdata(vdata<0.75)));
text(log(0.03),0.65,['\rho (log V_d_a_t_a , log v_m_o_d_e_l_ _\omega_i  ) = ', num2str(a(1,2),2)]);
aa=corrcoef(log(v2(vdata<0.75)),log(vdata(vdata<0.75)));
text(log(0.03),0.6,['\rho (log V_d_a_t_a , log v_m_o_d_e_l_ _u_n_i_f_o_r_m_ _\omega ) = ', num2str(aa(1,2),2)]);


