% Feb 28,  2006 calibration22dtu
%
% This file calibrates L=lambda to the world distribution of GDP
% It requires to have the programs:
%       phiL.m, Z.m. T.m, price_pm.m, eqT.m, findL.m, inputs.m, outputeq.m, outputcal2.m, dataload.
% and the data:
%       gdppercapitadata.m, countrycodes.m and datatrade.m
% this file creates figure 7.3 c
%
% It uses tariff from wto but it zeros the tariffs from those countries in
% trade unions, as described in blockmatrix
%
% the parameter delta0 needs to be set in this file

clear all;

% Step 1: set the inputs
inputs ;        

% Step 2: load the data
dataload ;

% load distance data
dmatrix;

% nomrmalize distance so average distance is 1
dist = distancematrix / ( (N/(N-1))* mean(mean(distancematrix)) );

delta0 = 0.3; % elasticity of trade cost to distance
%kappa0 = min(kappa*exp(delta0),1);
kappa0 = 1;
for i=1:N
    for j=1:N
            K(i,j) = kappa0*exp(-delta0*dist(i,j));
    end
end

mmK = mean(mean(K));
% use that: mmK =  N/(N^2) + (N^2-N)/(N^2) mk;
mK = (mmK - N/(N^2)) / ( (N^2-N)/(N^2) );
% mK is the average distance of among countries i ,j
% the next lines make sure that the country with the average distance
% has kappa = kappa0
kappa0 = 0.75; 
K = kappa0* K *(1/mK);

for i=1:N
    K(i,i) = 1;
end;


close all; % close graphs created by dataload

shareGDPcal = shareGDPdata;
shareGDPcal = shareGDPcal/sum(shareGDPcal);


% Model with tariff from the data
    
    % loads block a matrix with 1 for the countries in a trade union
    blockmatrix ;
    OM = block;
    % assigns values to matrix OM of tariffs using data
    for i=1:N
        %OM(i,1:N) = 1 - .5*(tariffwb(i)+tariffwto(i))/100;
        for j=1:N
            if OM(i,j) == 0;
                OM(i,j) = 1 - tariffwto(i)/100;
            end
        end
        OM(i,i) = 1;
    end;
           
    KOM  = (K.*OM).^(1/theta); %

    % Step 3: run the program to calibrate lambda = L:
    outputcal2;

    % store relevant info
    v1 = v;
    w1 = w;


% Model with uniform tariffs
    
    % avgtar = mean(tariffwto/100); set tariff equal to average in data
    avgtar = .1;  % set 10% tariff
    omega = 1-avgtar;
    OM = ones(N,N)*omega;
    for i=1:N
        OM(i,i) = 1;
    end;
    KOM  = (K.*OM).^(1/theta); %

    % Step 3: run the program to calibrate lambda = L:
    outputcal2;

    % store relevant info
    v2 = v;
    w2 = w;
   

    
a = ones(1,1);
clear a;

close all;

figure(1)
plot(log(shareGDPcal),vdata,'bo',log(shareGDPcal),v2,log(shareGDPcal),v1,'k*')
title({'FIGURE 7.3.c: VOLUME VERSUS SIZE using distance \kappa_i_j = \kappa_0 exp(-\delta_0 d_i_j)',...
    'Data (o),  Model w/uniform tariffs (solid),  Model w/tariffs from Table 2 (*) incorporating trade aggrements'})
xlabel({'COUNTRY SIZE: log of share of GDP', 'Correlations computed for countries with trade volume < 0.75'})
ylabel('IMPORTS TO GDP RATIO')
grid on;
axis([log(0.002),log(0.3),0,0.75])
text(log(0.13),0.7,'Parameters');
text(log(0.13),0.65,['\alpha = ',num2str(alpha)]);
text(log(0.13),0.6,['\beta = ',num2str(beta)]);
text(log(0.13),0.55,['\kappa_0 = ',num2str(kappa0,2)]);
text(log(0.13),0.5,['\omega_u_n_i_f_o_r_m = ',num2str(omega,2)]);
text(log(0.13),0.45,['\theta = ',num2str(theta)]);
text(log(0.13),0.4,['\delta_0 = ',num2str(delta0)]);

vmax = 0.75;

a=corrcoef(log(v1(vdata<vmax)),log(vdata(vdata<vmax)));
text(log(0.015),0.65,['\rho (log V_d_a_t_a , log v_m_o_d_e_l_ _\omega_i  ) = ', num2str(a(1,2),2)]);
aa=corrcoef(log(v2(vdata<vmax)),log(vdata(vdata<vmax)));
text(log(0.015),0.6,['\rho (log V_d_a_t_a , log v_m_o_d_e_l_ _u_n_i_f_o_r_m_ _\omega ) = ', num2str(aa(1,2),2)]);


