% March 23, 2004, load data set
%
% This script 
% 1) loads the data, 
% 2) produces two tables that display the data,
% 3) run regressions of trade volumen into share of GDP and tariffs, and
% 4) produce variaty of plots to see the data.
%
% Make sure to scroll up the screen if you want to see the Table 1 and 2.


datatrade;          % run script that loads datatrade, names variables
countrycodes;       % run script that creates codes, srtring with 3 letter abrebiated country names
gdppercapitadata;   % run scrip that loads gdp percapita data

N=60; % number of countries
Nseries=7;

% appends the gdp per capita to the rest of the trade data
tradedata = [tradedata, gdppercapita(1:N,1)/gdppercapita(1,1)];


% assign world bank tariff to wto tariff in case of missing values:
% for switzerlaand:
tradedata(18,6) = tradedata(18,5);
% for Kazakhstan
tradedata(57,6) = tradedata(57,5);
% Sri Lanka
tradedata(60,6) = tradedata(60,5);

% Process the data with respect to missing obervations 
tradedatam = tradedata ; % keep the original data with missing values
countrym = zeros(N,1)  ; % zero denotes that there are no missing values for that country


% identify the number of missisng values for each series, nmissing
% compute means for non-missing data
for j=1:Nseries;
    nmissing(j)=0;
    accumulate(j)=0;
    for i=1:N
        if tradedata(i,j) < 0.0 
            nmissing(j)=nmissing(j)+1;  % counter of the # of missing values
            countrym(i)=1;              % counter that country i has a missing value
        else
            accumulate(j)=accumulate(j)+tradedata(i,j);
        end
    end
end

nonmissmean = accumulate ./ (N-nmissing); 

for j=1:Nseries; 
    for i=1:N
        if tradedata(i,j) < 0.0 
           tradedata(i,j)= nonmissmean(j);
           tradedatam(i,j) = -0.99 ;
        end
    end
end

for i=1:N
    space(i,1:6) = '      ';
end

% construct a data set w/o the countries w/missing info: tradedatanom
j=1;
i=j;
while (i<N+1)
    if countrym(i) == 0;
        tradedatanom(j,1:Nseries) = tradedatam(i,1:Nseries);
        codesnom(j,1:3) = codes(i,1:3);
        i=i+1;
        j=j+1;
    else
        i=i+1;
    end
end

Nnom = max(size(tradedatanom)); % number of countries with no missing data
  
for i=1:Nnom
    spacenom(i,1:6) = '      ';
end

% Data set where missing data have been replaced by average
shareGDPdata = tradedata(1:N,1);
vdata = tradedata(1:N,2);          % trade volume
ptradtonontc = tradedata(1:N,3);   % relative price of tradeable to non-tradeable consumption
pmachtocons  = tradedata(1:N,4);   % relative price of consumption to machinery and equiptment
tariffwb     = tradedata(1:N,5);   % tariff from WB measured as reveneu/Imports
tariffwto    = tradedata(1:N,6);   % tariff from WTO based on legislated rates
gdppercap    = tradedata(1:N,7);   % GDP per capita, PWT, USA=1;

disp('*******************************************************************************************************************')
disp(' ')
disp('                 TABLE 1: 60 COUNTRIES ')
disp(' ')
disp('Country GDP share .5(I+E)/GDP PCT/PCNI PI/PC  tariff   tariff  GDP/POP');
disp('           (1)       (2)       (3)      (4)     (5)      (6)     (7)  ');
disp(' ');
disp([codes,space,num2str(tradedatam,2)]);
disp(' ')
disp(' -0.99 denotes missing values')
disp('(1): share in world gdp. From WDI 2002 cdRom, average 1994-2000')
disp('(2): 0.5*(exp+imp)/GDP. From WDI 2002 cdRom,, average 1994-2000')
disp('(3): relative price of tradeable consumption v.s. non-tradeable consumption goods, from the benchmark PWT year 1996.')
disp('(4): price of machinery and equipment relative to consumption, from benchmark PWT year 1996. ')
disp('(5): Average 1996-2000 import duties over imports. Taken from WDI2002 cdRom, except for countries in the european union')
disp('(6): Average 1996-2000 ad-valorem tariff rate, from Dollar and Kraay, Source: worldbank database (WTO)')
disp('(7): Per capita GDP, PPP adjusted, USA=1, from PWT');
disp(' ');

% Data set without countries with missing values
shareGDPdatanom = tradedatanom(1:Nnom,1);   % share of GDP in world
vdatanom        = tradedatanom(1:Nnom,2);   % trade volume
ptradtonontcnom = tradedatanom(1:Nnom,3);   % relative price of tradeable to non-tradeable consumption
pmachtoconsnom  = tradedatanom(1:Nnom,4);   % relative price of consumption to machinery and equiptment
tariffwbnom     = tradedatanom(1:Nnom,5);   % tariff from WB measured as reveneu/Imports
tariffwtonom    = tradedatanom(1:Nnom,6);   % tariff from WTO based on legislated rates
gdppercapnom    = tradedatanom(1:Nnom,7);   % GDP per capita, PWT, USA=1;

disp('*******************************************************************************************************************')
disp(' ')
disp('         TABLE 2: WITHOUT COUNTRIES WITH MISSING VALUES')
disp(' ')
disp('Country GDP share .5(I+E)/GDP PCT/PCNI PI/PC  tariff   tariff  GDP/POP');
disp('           (1)       (2)       (3)      (4)     (5)      (6)     (7)    ');
disp(' ');
disp([codesnom,spacenom,num2str(tradedatanom,2)]);
disp(' ')
disp('(1): share in world gdp. From WDI 2002 cdRom, average 1994-2000')
disp('(2): 0.5*(exp+imp)/GDP. From WDI 2002 cdRom,, average 1994-2000')
disp('(3): relative price of tradeable consumption v.s. non-tradeable consumption goods, from the benchmark PWT year 1996.')
disp('(4): price of machinery and equipment relative to consumption, from benchmark PWT year 1996. ')
disp('(5): Average 1996-2000 import duties over imports. Taken from WDI2002 cdRom, except for countries in the european union')
disp('(6): Average 1996-2000 ad-valorem tariff rate, from Dollar and Kraay, Source: worldbank database (WTO)')
disp('(7): Per capita GDP, PPP adjusted, USA=1, from PWT');
disp(' ');
disp('*******************************************************************************************************************')



% REGRESSIONS: trade volume into Share of GDP and tariffs

disp(' ');
disp('-----------------------------------------------------------------  ')
disp('Regression Equation : log(v) = b0 + b1 log(share GDP) + b2 tariff  ')
disp('-----------------------------------------------------------------  ')
disp(' ')
%[b,RR] = regression(log(vdatanom),[ones(Nnom,1),log(shareGDPdatanom),.5*(tariffwbnom+tariffwtonom)]);
[b,RR] = regression(log(vdatanom),[ones(Nnom,1),log(shareGDPdatanom),tariffwtonom]);
disp('Excluding countries with missing data, N = 46')
disp(['regression coefficients b = ', num2str(b',2)]);
disp(['R square = ', num2str(RR,2)]);
disp('  ')
disp(' ')
%[b,RR] = regression(log(vdata),[ones(N,1),log(shareGDPdata),.5*(tariffwb+tariffwto)]);
[b,RR] = regression(log(vdata),[ones(N,1),log(shareGDPdata),tariffwto]);
disp('All countries, assigning average to missing values, N=60')
disp(['regression coefficients b = ', num2str(b',2)]);
disp(['R square = ', num2str(RR,2)]);
disp('  ')
disp('Note that tariffs are measures in percentages')
disp('  ')
disp('  ')

disp('---------------------------------------------------------------------- ')
disp('Regression Equation : log(v) = b0 + b1 log(share GDP) + b2 log(tariff) ')
disp('---------------------------------------------------------------------- ')
disp(' ')
%[b,RR] = regression(log(vdatanom),[ones(Nnom,1),log(shareGDPdatanom),log(.5*(tariffwbnom+tariffwtonom))]);
[b,RR] = regression(log(vdatanom),[ones(Nnom,1),log(shareGDPdatanom),log(max(1e-15,tariffwtonom))]);
disp('Excluding countries with missing data, N = 46')
disp(['regression coefficients b = ', num2str(b',2)]);
disp(['R square = ', num2str(RR,2)]);
disp('  ')
disp('  ')
%[b,RR] = regression(log(vdata),[ones(N,1),log(shareGDPdata),log((tariffwb+tariffwto)*.5)]);
[b,RR] = regression(log(vdata),[ones(N,1),log(shareGDPdata),log(max(1e-15,tariffwto))]);
disp('All countries, assigning average to missing values, N=60')
disp(['regression coefficients b = ', num2str(b',2)]);
disp(['R square = ', num2str(RR,2)]);
disp('  ')
disp('  ')
disp('  ')

disp('-------------------------------------------------------------------------- ')
disp('Regression Equation : log(PI/PC) = b0 + b1 log(GDP/PoP) + b2 log(1+tariff) ')
disp('-------------------------------------------------------------------------- ')
disp(' ')
[b,RR] = regression(log(pmachtoconsnom),[ones(Nnom,1),log(gdppercapnom),log(1+.5*(tariffwbnom+tariffwtonom)/100)]);
disp('Excluding countries with missing data, N = 46')
disp(['regression coefficients b = ', num2str(b',2)]);
disp(['R square = ', num2str(RR,2)]);
disp('  ')
disp('correlation matrix between: ')
disp(' ' )
disp('PI/PC   GDP/POP   1+tariff')
disp('  ')
disp(num2str(corrcoef([log(pmachtoconsnom),log(gdppercapnom),log(1+.5*(tariffwbnom+tariffwtonom)/100)]),3));
disp('  ')
disp('all variables in logs')
disp('  ')
disp('  ')

disp('-------------------------------------------------------------------------- ')
disp('Regression Equation : log(PI/PC) = b0 + b1 log(GDP/PoP) + b2 tariff ')
disp('-------------------------------------------------------------------------- ')
disp(' ')
[b,RR] = regression(log(pmachtoconsnom),[ones(Nnom,1),log(gdppercapnom),.5*(tariffwbnom+tariffwtonom)/100]);
disp('Excluding countries with missing data, N = 46')
disp(['regression coefficients b = ', num2str(b',2)]);
disp(['R square = ', num2str(RR,2)]);
disp('  ')
disp('correlation matrix between: ')
disp(' ' )
disp('PI/PC   GDP/POP   tariff')
disp('  ')
disp(num2str(corrcoef([log(pmachtoconsnom),log(gdppercapnom),.5*(tariffwbnom+tariffwtonom)]),3));
disp('  ')
disp('PI/PC and GDP/POP in logs, tariff in levels ')
disp(' ')
disp(' ')

disp('----------------------------------------------------------------------------- ')
disp('Regression Equation : log(PTC/PNTC) = b0 + b1 log(GDP/PoP) + b2 log(1+tariff) ')
disp('----------------------------------------------------------------------------- ')
disp(' ')
[b,RR] = regression(log(ptradtonontcnom),[ones(Nnom,1),log(gdppercapnom),log(1+.5*(tariffwbnom+tariffwtonom)/100)]);
disp('Excluding countries with missing data, N = 46')
disp(['regression coefficients b = ', num2str(b',2)]);
disp(['R square = ', num2str(RR,2)]);
disp('  ')
disp('correlation matrix between: ')
disp(' ' )
disp('PTC/PNTC GDP/POP  1+tariff')
disp('  ')
disp(num2str(corrcoef([log(ptradtonontcnom),log(gdppercapnom),log(1+.5*(tariffwbnom+tariffwtonom)/100)]),3));
disp('  ')
disp('all variables in logs')
disp('  ')
disp('  ')

disp('---------------------------------------------------------------------- ')
disp('Regression Equation : log(PTC/PNTC) = b0 + b1 log(GDP/PoP) + b2 tariff')
disp('---------------------------------------------------------------------- ')
disp(' ')
[b,RR] = regression(log(ptradtonontcnom),[ones(Nnom,1),log(gdppercapnom),.5*(tariffwbnom+tariffwtonom)/100]);
disp('Excluding countries with missing data, N = 46')
disp(['regression coefficients b = ', num2str(b',2)]);
disp(['R square = ', num2str(RR,2)]);
disp('  ')
disp('correlation matrix between: ')
disp(' ' )
disp('PTC/PNTC GDP/POP   tariff')
disp('  ')
disp(num2str(corrcoef([log(ptradtonontcnom),log(gdppercapnom),.5*(tariffwbnom+tariffwtonom)/100]),3));
disp('  ')
disp('PTC/PNTC and GDP/POP in logs, tariff in levels -in %')
disp(' ')



% PLOTS

grid on;

figure(1);
plot(shareGDPdata,vdata,'b*')
title('VOLUME OF TRADE VS SIZE')
xlabel('Share of World GDP');
ylabel('(Imporst+Exports)/(2*GDP) ')
grid on;

figure(2);
plot(log(shareGDPdata),vdata,'b*')
title('VOLUME OF TRADE VS SIZE')
xlabel('Log of Share of World GDP');
ylabel('(Imporst+Exports)/(2*GDP) ')
grid on;

figure(3);
plot(log(shareGDPdata),log(vdata),'b*')
title('VOLUME OF TRADE VS SIZE')
xlabel('Log of Share of World GDP');
ylabel('(og of (Imporst+Exports)/(2*GDP) ')
grid on;

figure(4)
plot(log(pmachtocons),log(ptradtonontc),'b*');
title('TWO MEASURES OF PRICE OF NON-TRADEABLES TO TRADEABLES')
xlabel('log of Price of Machinery and Equipment to Price of Consumption')
ylabel('log of Price of Tradeable Consumption to Non-Tradeable Consumption')
grid on;

figure(5)
plot(gdppercapnom,log(ptradtonontcnom),'b*');
title('RELATIVE PRICES VS PER CAPITA GDP');
xlabel('Per capita GDP, PPP adjusted, USA=1')
ylabel('Price of Tradeable Consumption to Non Tradeable Consumption, in logs')
grid on;

figure(6)
plot(gdppercapnom,log(pmachtoconsnom),'b*')
title('RELATIVE PRICES VS PER CAPITA GDP')
xlabel('Per capita GDP, PPP adjusted, USA=1')
ylabel('Price of Machinery and Equipment to Consumption, in logs')
grid on;

figure(7)
plot(tariffwb,tariffwto,'b*');
title('TWO MEASURES OF IMPORTS TARIFFS')
xlabel('Revenue of Import duties / Value of Imports, in %')
ylabel('Average tariff acorss products, in %')
grid on;

figure(8)
plot(tariffwtonom,log(vdatanom),'b*');
title('TARIFFS VS TRADE VOLUME')
ylabel('Log of (Imp+Exp)/(2*GDP) ')
xlabel('Average tariff acorss products, in %')
grid on;

figure(9)
plot(tariffwbnom,log(vdatanom),'b*');
title('TARIFFS VS TRADE VOLUME')
ylabel('Log of (Imp+Exp)/(2*GDP) ')
xlabel('Tariff (from Revenue/Imports) in %')
grid on;

figure(10)
plot(.5*(tariffwbnom+tariffwtonom),log(vdatanom),'b*');
title('TARIFFS VS TRADE VOLUME')
ylabel('(Imp+Exp)/(2*GDP) ')
xlabel('Average of the two tariff measures in %')
grid on;

figure(11)
plot(log(.5*(tariffwbnom+tariffwtonom)),log(vdatanom),'b*');
title('TARIFFS VS TRADE VOLUME')
ylabel('(Imp+Exp)/(2*GDP) ')
xlabel('Log of Average of the two tariff measures in %')
grid on;

figure(12)
plot(.5*(tariffwbnom+tariffwtonom),log(gdppercapnom),'b*');
title('TARIFFS VS GDP/POP')
ylabel('GPD/POP ')
xlabel('Average of the two tariff measured in %')
grid on;

figure(13)
plot(.5*(tariffwbnom+tariffwtonom),log(pmachtoconsnom),'b*');
title('TARIFFS VS PRICE OF INVESTMENT RELATIVE TO CONS')
ylabel('Log PI/PC ')
xlabel('Average of the two tariff measured in %')
grid on;

figure(14)
plot(.5*(tariffwbnom+tariffwtonom),log(pmachtoconsnom),'b*');
title('TARIFFS VS PRICE OF TRADEABLE TO NONTRADEABLE CONSUMPTION')
ylabel('Log PTC/PNTC ')
xlabel('Average of the two tariff measured in %')
grid on;
