% Ths file computes the welfare gains of going from autarchy to free and
% costless trade for the symmetryc model with n countries of the same size
% Each also computes the volume of trade
% Runing this program produces figures 6.1 to 6.5 as well as some numbers mentioned in the tex file


% written by Fernando Alvarez, Feb 28, 2006

clear all;

% Reads the data using dataload
dataload;
close all;


% Baseline Parameters:

alpha = 0.75;   % share of value added on final goods production function (0.9)
beta  = 0.5 ;   % share of value added on materials goods production function (0.35)
theta = 0.15;   % variance of individual productivities  (0.25)



% ***************************************************************************

% Part I: Table comparing Autarchy vs Free Trade

nvalues = [3.4, 10, 200] ;   % grid with the number of countries in the world

disp( '   ');
disp( 'Parameters' );
disp('  ');
disp([' \theta = ', num2str(theta)])
disp([' \beta  = ', num2str(beta)])
disp([' \alpha = ', num2str(alpha)])
disp('   ');
disp('-----------------------------------------------')


for i=1: max(size(nvalues));

% Lambda : (log) proportional change in consumption between
% autarhy and free trade based 

n = nvalues(i);

Lambda = (theta/beta)*( 1-alpha )*log(n) ;


disp('  ')
disp( 'Benefits of going from autarchy to free trade')
disp( 'in permanent consumption equivalent units')
disp(' ')
disp([' number of countries n = ', num2str(n)])
disp([' size of each country  ', num2str(1/n)])
disp(' ');
disp([' Lambda = ', num2str(Lambda)])
disp( ' ');
disp('-----------------------------------------------')

end;

% ***************************************************************************

%%% Set default value for kappa for Figures 7.1-7.5:

kappa = 0.75;

sizecountry = [0.0004:0.001:0.35];  % grid for values of size of country, i.e. 1/n


% Gains of Trade: Figures 7.1

thetavec = [0.1,0.15,0.25];      % grid for values of theta



% part III: Gains of Trade: Figures 7.1


thetavec = [0.1,0.15,0.25]; % grid for values of theta

% benchmark values:
omega = 0.9
     
for i=1: max(size(sizecountry));
    
    n = 1/sizecountry(i);
    
    for j = 1: max(size(thetavec));
    
        theta = thetavec(j);
        
        % ratio of p0/p
        p0top = ( 1 + (n-1)*(kappa)^(1/theta) ) /  ( 1 + (n-1)*(kappa*omega)^(1/theta) )  ;
        p0top = p0top^(theta*(1-alpha)/beta);
        
        % nominal gdpg at tariff, 1+I(1-omega) 
        nomgdp0 =  beta + (n-1)*(kappa*omega)^(1/theta)*(1-omega+omega*beta) ;
        nomgdp0 = nomgdp0 / ( beta + (n-1)*(kappa*omega)^(1/theta) * ( alpha*(1-omega)+omega*beta ) ) ;
        
        % ratio of consumptions
        ctoc0 = p0top / nomgdp0 ;
        
        % welfare gain
          wgain(i,j) = log(ctoc0) ;       
        
    end
end

wgain = wgain*100; % measure the welfare gain in %

figure(1)
plot(sizecountry,wgain(:,1),'-',sizecountry,wgain(:,2),'-',sizecountry,wgain(:,3),'-')
title({['FIGURE 6.1: WELFARE GAINS FROM ELIMINATING A ' num2str(100*(1-omega),2),'% TARIFF'],['Three values of dispersion ','\theta']}')
ylabel('WELFARE GAIN IN PERCENT: log difference in consumption x 100')
xlabel('COUNTRY SIZE: fraction of world GDP');
grid;
dx = max(max(sizecountry)) - min(min(sizecountry)) ;
xlow = min(min(sizecountry));
dy = max(max(wgain)) - min(min(wgain)) ;
ylow = min(min(wgain));
axis([0.0001, 0.35, 0, 1]);
text( xlow+.875*dx, ylow+dy*.6, ['\omega = ', num2str(omega)]);
text( xlow+.875*dx, ylow+dy*.675, ['\kappa = ', num2str(kappa)]);
text( xlow+.875*dx, ylow+dy*.75, ['\beta = ', num2str(beta)]);
%text( xlow+.875*dx, ylow+dy*.85, ['\omega = ', num2str(omega)]);
text( xlow+.875*dx, ylow+dy*.825, ['\alpha = ', num2str(alpha)]);
text( xlow+.875*dx, ylow+dy*.9, 'Parameters ');

text(sizecountry(5)+0.005,wgain(5,1)+0.005,['\theta = ',num2str(thetavec(1))]);
text(sizecountry(70)+0.01,wgain(70,2)+0.01,['\theta = ',num2str(thetavec(2))]);
text(sizecountry(200)+0.01,wgain(200,3)+0.01,['\theta = ',num2str(thetavec(3))]);
 

% ***************************************************************************

% part IV: Gains of Trade: OLD Figures 6.2


omegavec = [0.8,0.7,0.6];         % grid for values of omega

% benchmark value
theta = 0.15;
     

for i=1: max(size(sizecountry));
    
    n = 1/sizecountry(i);
    
    for j = 1: max(size(thetavec));
    
        
        omega = omegavec(j);
        
        % ratio of p0/p
        p0top = ( 1 + (n-1)*(kappa)^(1/theta) ) /  ( 1 + (n-1)*(kappa*omega)^(1/theta) )  ;
        p0top = p0top^(theta*(1-alpha)/beta);
        
        % nominal gdpg at tariff, 1+I(1-omega) 
        nomgdp0 =  beta + (n-1)*(kappa*omega)^(1/theta)*(1-omega+omega*beta) ;
        nomgdp0 = nomgdp0 / ( beta + (n-1)*(kappa*omega)^(1/theta) * ( alpha*(1-omega)+omega*beta ) ) ;
        
        % ratio of consumptions
        ctoc0 = p0top / nomgdp0 ;
        
        % welfare gain
          wgain(i,j) = log(ctoc0) ;       
        
    end
end

wgain = wgain*100; % measure the welfare gain in %

figure(2)
plot(sizecountry,wgain(:,1),'-',sizecountry,wgain(:,2),'-',sizecountry,wgain(:,3),'-')
title({['*** OLD *** FIGURE 6.2: WELFARE GAINS FROM ELIMINATING A TARIFF FACTOR \omega'],['Three values of ','\omega']}')
ylabel('WELFARE GAIN IN PERCENT: log difference in consumption x 100')
xlabel('COUNTRY SIZE: fraction of world GDP');
grid;
dx = max(max(sizecountry)) - min(min(sizecountry)) ;
xlow = min(min(sizecountry));
dy = max(max(wgain)) - min(min(wgain)) ;
ylow = min(min(wgain));
text( xlow+.875*dx, ylow+dy*.65, ['\theta = ', num2str(theta)]);
text( xlow+.875*dx, ylow+dy*.725, ['\kappa = ', num2str(kappa)]);
text( xlow+.875*dx, ylow+dy*.8,['\beta = ', num2str(beta)]);
text( xlow+.875*dx, ylow+dy*.875, ['\alpha = ', num2str(alpha)]);
text( xlow+.875*dx, ylow+dy*.95, 'Parameters ');

text(sizecountry(20)+0.01,wgain(20,1)+0.2,['\omega = ',num2str(omegavec(1))]);
text(sizecountry(50)+0.01,wgain(50,2)+0.1,['\omega = ',num2str(omegavec(2))]);
text(sizecountry(200)+0.01,wgain(200,3)+0.1,['\omega = ',num2str(omegavec(3))]);



% ***************************************************************************

% part V: Volume of Trade: OLD Figures 6.3 

% benchmark value
omega = 0.9;

thetavec = [0.1, 0.15, 0.25];

for i = 1 : max(size(sizecountry));
    
    n = 1/sizecountry(i);
    
    for j = 1 : max(size(omegavec));
        
        theta = thetavec(j);
                
        % v = import to GDP ratio:
        inter = omega + 1 /( (n-1)*(kappa*omega)^(1/theta) ) ;
        v(i,j) = (1-alpha) / ( 1 - omega + beta*inter ); 

    end ;
    
end;

figure(3)
plot(sizecountry,v(:,1),'-',sizecountry,v(:,2),'-',sizecountry,v(:,3),'-')
title({'*** OLD **** FIGURE 6.3: VOLUME OF TRADE', ['Three values of dispersion parameter ','\theta']}')
ylabel('IMPORT TO GDP RATIO: v')
xlabel('COUNTRY SIZE: fraction of world GDP');
grid;
dx = max(max(sizecountry)) - min(min(sizecountry)) ;
xlow = min(min(sizecountry));
dy = max(max(v)) - min(min(v)) ;
ylow = min(min(v));
text( xlow+.875*dx, ylow+dy*.675, ['\omega = ', num2str(omega)]);
text( xlow+.875*dx, ylow+dy*.75, ['\kappa = ', num2str(kappa)]);
text( xlow+.875*dx, ylow+dy*.825, ['\beta = ', num2str(beta)]);
text( xlow+.875*dx, ylow+dy*.9, ['\alpha = ', num2str(alpha)]);
text( xlow+.875*dx, ylow+dy*.975, 'Parameters ');

text(sizecountry(35)+0.01,v(35,1)+0.001,['\theta = ',num2str(thetavec(1))]);
text(sizecountry(80)+0.01,v(80,2)+0.001,['\theta = ',num2str(thetavec(2))]);
text(sizecountry(200)+0.01,v(200,3)+0.001,['\theta = ',num2str(thetavec(3))]);



% ***************************************************************************


% part VI: Volume of Trade: OLD Figure 6.4 

% benchmark value
theta = 0.15;

omegavec = [0.7, 0.8, 0.9];

for i = 1 : max(size(sizecountry));
    
    n = 1/sizecountry(i);
    
    for j = 1 : max(size(omegavec));
        
        omega = omegavec(j);
                
        % v = import to GDP ratio:
        inter = omega + 1 /( (n-1)*(kappa*omega)^(1/theta) ) ;
        v(i,j) = (1-alpha) / ( 1 - omega + beta*inter ); 

    end ;
    
end;

figure(4)
plot(sizecountry,v(:,1),'-',sizecountry,v(:,2),':',sizecountry,v(:,3),'--')
title({'*** OLD *** FIGURE 6.4: VOLUME OF TRADE', ['Three values of tariff factor ','\omega']}')
ylabel('IMPORT TO GDP RATIO: v')
xlabel('COUNTRY SIZE: fraction of world GDP');
grid;
dx = max(max(sizecountry)) - min(min(sizecountry)) ;
xlow = min(min(sizecountry));
dy = max(max(v)) - min(min(v)) ;
ylow = min(min(v));
text( xlow+.875*dx, ylow+dy*.675, ['\theta = ', num2str(theta)]);
text( xlow+.875*dx, ylow+dy*.75, ['\kappa = ', num2str(kappa)]);
text( xlow+.875*dx, ylow+dy*.825,['\beta = ', num2str(beta)]);
text( xlow+.875*dx, ylow+dy*.9, ['\alpha = ', num2str(alpha)]);
text( xlow+.875*dx, ylow+dy*.975, 'Parameters ');


text(sizecountry(35)+0.01,v(35,1)+0.001,['\omega = ',num2str(omegavec(1))]);
text(sizecountry(80)+0.01,v(80,2)+0.001,['\omega = ',num2str(omegavec(2))]);
text(sizecountry(200)+0.02,v(200,3)+0.001,['\omega = ',num2str(omegavec(3))]);


% % ***************************************************************************


% part VI: Volume of Trade: Figures 6.2 

omega = omegavec(3);

figure(5)
plot(log(shareGDPdata),vdata,'ko',log(sizecountry),v(:,3),'-')
title('FIGURE 6.2: VOLUME OF TRADE')
ylabel('IMPORT TO GDP RATIO')
xlabel('COUNTRY SIZE:  log of fraction of world GDP');
grid;
dx = max(max(log(shareGDPdata))) - min(min(log(shareGDPdata))) ;
xlow = min(min(log(shareGDPdata)));
dy = max(max(vdata)) - min(min(vdata)) ;
ylow = min(min(vdata));
text( xlow+.875*dx, ylow+dy*.6, ['\theta = ', num2str(theta)]);
text( xlow+.875*dx, ylow+dy*.675, ['\omega = ', num2str(omega)]);
text( xlow+.875*dx, ylow+dy*.75, ['\kappa = ', num2str(kappa)]);
text( xlow+.875*dx, ylow+dy*.825, ['\beta = ', num2str(beta)]);
text( xlow+.875*dx, ylow+dy*.9, ['\alpha = ', num2str(alpha)]);
text( xlow+.875*dx, ylow+dy*.975, 'Parameters ');

%i = 22;
%text(log(sizecountry(i))+0.05,v(i,3),'Model') 

% Singapore i = 39;
i=39;
text(log(shareGDPdata(i))+0.1,vdata(i),'Singapore')
% Hong Kong i = 25
i=25;
text(log(shareGDPdata(i))+0.1,vdata(i),'Hong Kong')
% Malaysia i = 38
i = 38;
text(log(shareGDPdata(i))+0.1,vdata(i),'Malaysia')
i = 1;
text(log(shareGDPdata(i))+0.05,vdata(i),'USA')
i = 2;
text(log(shareGDPdata(i))+0.1,vdata(i)-0.01,'Japan')
i = 17;
text(log(shareGDPdata(i))+0.1,vdata(i)-0.01,'Argentina')
i = 19;
text(log(shareGDPdata(i))+0.1,vdata(i),'Belgium')
i = 50;
text(log(shareGDPdata(i))+0.1,vdata(i),'Ukraine')
i = 51;
text(log(shareGDPdata(i))+0.1,vdata(i)-0.01,'Bangladesh')
i = 3;
text(log(shareGDPdata(i))+0.1,vdata(i),'Germany')




% ***************************************************************************


% part II: Gains of Trade: OLD Figure 7.1


omega = 0.0;
     

for i=1: max(size(sizecountry));
    
    n = 1/sizecountry(i);
    
    for j = 1: max(size(thetavec));
    
        theta = thetavec(j);
        
        % ratio of p0/p
        p0top = ( 1 + (n-1)*(kappa)^(1/theta) ) /  ( 1 + (n-1)*(kappa*omega)^(1/theta) )  ;
        p0top = p0top^(theta*(1-alpha)/beta);
        
        % nominal gdpg at tariff, 1+I(1-omega) 
        nomgdp0 =  beta + (n-1)*(kappa*omega)^(1/theta)*(1-omega+omega*beta) ;
        nomgdp0 = nomgdp0 / ( beta + (n-1)*(kappa*omega)^(1/theta) * ( alpha*(1-omega)+omega*beta ) ) ;
        
        % ratio of consumptions
        ctoc0 = p0top / nomgdp0 ;
        
        % welfare gain
          wgain(i,j) = log(ctoc0) ;       
        
    end
end

wgain = wgain*100; % measure the welfare gain in %

figure(6)
plot(sizecountry,wgain(:,1),'-',sizecountry,wgain(:,2),'-',sizecountry,wgain(:,3),'-')
title({'*** OLD *** FIGURE 6.1: WELFARE GAINS FROM GOING FROM AUTARCHY TO FREE TRADE',['Three values of dispersion ','\theta']}')
ylabel('WELFARE GAIN IN PERCENT: log difference in consumption x 100')
xlabel('COUNTRY SIZE: fraction of world GDP');
grid;

dx = 0.35;
xlow = 0;
dy = 60; ;
ylow = 0; 
axis([0 0.35 0 60])
%text( xlow+.875*dx, ylow+dy*.75,['\omega = ', num2str(omega)]);
text( xlow+.875*dx, ylow+dy*.675, ['\kappa = ', num2str(kappa)]);
text( xlow+.875*dx, ylow+dy*.75, ['\beta = ', num2str(beta)]);
text( xlow+.875*dx, ylow+dy*.825, ['\alpha = ', num2str(alpha)]);
text( xlow+.875*dx, ylow+dy*.9, 'Parameters ');

text(sizecountry(15)+0.001,wgain(15,1)+01,['\theta = ',num2str(thetavec(1))]);
text(sizecountry(35)+0.005,wgain(35,2)+1,['\theta = ',num2str(thetavec(2))]);
text(sizecountry(75)+0.005,wgain(75,3)+1,['\theta = ',num2str(thetavec(3))]);




% ***************************************************************************



