% March 23, 2004
% This file sets up the parameter values of the model
% global N alpha eta theta beta K omega OM L lambda A B KOM; 
% sets all these parameters, as well as w0.
% contains several settings of L, lambda, Kappa, and Ommega
% to change setting, comment out the ones you don't want to use

clear all;
% declare global variables that will be used by other functions
global N alpha eta theta beta K omega OM L lambda A B KOM; 

% **************************************************************************************************
% Set values for Basic Preferences and Technologies parameters
% **************************************************************************************************

N=60;          % number of countries
alpha = .75;   % share of non-tradeables
eta = 2;       % elasticity of substitution between tradeables
theta = .15;   % dispersion of productivities
beta = .5;     % share of labor in tradeables

if 1 + theta*(1-eta) < 0 
   disp('eta is too high relative to theta')
   disp('the integral defining the constnat A does not converge');
end

A = (gamma(1 + theta*(1-eta)))^(1/(1-eta));  % see equation (??) in the paper
B = beta^(-beta)*(1-beta)^(-1+beta);         % see equation (??) in the paper


% **************************************************************************************************
% Set values for tariffs Omega and Transporation Cost Kappa
% **************************************************************************************************

% simmetric tariff and transportation cost case:
kappa = 0.75  ; % uniform transportation cost factor
omega = 0.9  ;% uniform tariff factor 
K  = (1-kappa)*eye(N) + kappa*ones(N,N);  % tranportation cost factors kappa in the paper see eq (??)
OM = (1-omega)*eye(N) + omega*ones(N,N);  % tariff factors omega matrix, see eq(??) 

% Random matrix K and OM:
%K = rand(N,N);
%OM = rand(N,N);
%for i =1:N
%     K(i,i)=1;
%     OM(i,i) = 1;
%end

KOM  = (K.*OM).^(1/theta); % this will be used for computing pc and D.
                           % combined price effect of tariff and
                           % transportation cost

                           
% **************************************************************************************************
% Set values for distribution of Labor L and Productivities lambda
% **************************************************************************************************
                           
% This is only relevant to find an equilibrium, and not relevant for the calibration exercise

%L=ones(N,1);   % distribution of effective labor force
%L=linspace(1,N,N)' ;
L = exp(2.5*randn(N,1));

%L=rand(N,1);        % random choice to check code
%lambda =  3 * rand(N,1) .* L;   % random choice of lambda/L

%lambda=rand(N,1);   % random choice to check code
lambda=L;      % distriution of productivity parameter in tradeables

% normalize L and lambda in the simplex, without loss of generality
lambda = lambda / sum(lambda) ;
L = L / sum(L);


% **************************************************************************************************
% Set values for distribution of target GDP distribution Y, relative prices P
% **************************************************************************************************

% This is only relevant for the calibration exercise, and not relevant to find an equilibrium

% Target distribution of GDP for the calibration
shareGDPcal = rand(N,1);
shareGDPcal = shareGDPcal/sum(shareGDPcal);
% introduce some large countries
shareGDPcal(1) = 0.3;
shareGDPcal(2) = 0.2;
shareGDPcal(3) = 0.1;
shareGDPcal(4) = 0.05;
shareGDPcal(5:N,1) = 0.35*(shareGDPcal(5:N,1)/sum(shareGDPcal(5:N,1)));


% Target distribution of relative prices for the calibration
Pcal = rand(N,1);
Pcal = Pcal/sum(Pcal);
