% March 22, 2004 
% This program produces L and lambda consistent with GDP and relative prices given by
% shareGDPcal and Pcal.
% It requires inputs.m to be run first to initialize the parameters
% It uses the mapping phi  programmed in phi.m
% It produces interesting plots to analyze the calibrated economy

% declare global variables that will be used by other functions
global N alpha eta theta beta K omega OM L lambda A B KOM; 

% run inputs.m first

% ***********************************************************************************
% Finds fixed point lambda and L
%************************************************************************************

% finds L and lambda 
[lambdanew,Lnew] = findLandl(shareGDPcal,Pcal);

lambda = lambdanew;
L = Lnew;


% ***********************************************************************************
% check fixed point by computing equilibrium for new lambda and L
%************************************************************************************

%initial wages w0 based on the equilibrium for costless trade
for i=1: N
    w0(i,1) = ( lambda(i)/L(i) ) ^ (theta/(theta+beta));
end
% normalize intial wages:
w0 = w0 / (w0'*L);

[w,W,distdw,distZZ] = eqT(w0);

% price of tradeable aggregate pm:
pmguess = ones(N,1); %arbitrary guess of pm
pm = price_pm(w,pmguess);                           

% non-tradeable vs tradeable relative price P:
Delta = 1 / ( alpha^alpha * (1-alpha)^(1-alpha) ) ;
Plevel = Delta * ( (w ./ pm) .^alpha ) ;         
P = Plevel/sum(Plevel) ; % normalized vector of relative prices

% consumption price p
p = Delta *  (w .^alpha) .* (pm .^(1-alpha))  ;

% Call function Z to compute objects of interest at equilibrium wages
[ZZ,D,s,F] = Z(w);

for i=1:N
    Taxes(i,1)=0;
    for j=1:N
        Taxes(i,1) = D(i,j)*(1-OM(i,j)) + Taxes(i,1);
    end
    Taxes(i,1) =  L(i)*w(i) * (1-s(i)) * Taxes(i) / (beta*F(i)) ;
    GDP(i,1)   =  L(i)*w(i) + Taxes(i);
    Imp(i,1)   =  L(i)*w(i) * (1-s(i)) * ( 1 - D(i,i) ) / ( beta * F(i) );
end

% volume of trade = import GDP ratio v:
v = Imp ./ GDP;
% compute share of GDP in world GDP shareGDP:
shareGDP = GDP / sum(GDP);
% Taxes as Fraction of GDP
TaxesGDP = Taxes ./ GDP ;
% real consumption
c = GDP ./ (L .* p);


close all;

figure(1)
plot(ZZ./L)
title('Values of the excess demand Z at equilibrium wages')
ylabel('Excess demand as fraction of toatl labor, Z(i)/L(i) ')
xlabel('countries')

figure(2)
plot(shareGDP,v,'b*')
title('Volume of Trade vs Share of GDP in world GDP')
xlabel('Share in World GDP')
ylabel('Imports / GDP ');

figure(3)
plot(log(shareGDP),v,'b*')
title('Volume of Trade vs Share of GDP in world GDP')
xlabel('log Share in World GDP')
ylabel('Imports / GDP ');

figure(4)
plot(shareGDPcal,shareGDP,'b*')
title('Fit of Calibration; GDP')
xlabel(' target GDP ')
ylabel(' equilibrium GDP disribution ');

figure(5)
plot(Pcal,P,'b*')
title('Fit of Calibration; Relative Prices')
xlabel(' target relative prices ')
ylabel(' equilibrium relative prices ');

figure(6)
plot(log(L),log(lambda./L),'b*')
title('Calibrated Parameter values: L and lambda/L');
xlabel(' log(L) ')
ylabel(' log(lambda/L) ')

figure(7)
plot(log(L),log(lambda),'b*')
title('Calibrated Parameter values: L and lambda');
xlabel(' log(L) ')
ylabel(' log(lambda) ')
