% March 22, 2004 
% This program iterates on the wage vector usign T until
% convergence to an equilirium.
% It requires inputs.m to be run first to initialize the parameters
% It uses the mapping T  programmed in T.m
% It produces interesting plots to analyze the convergence of the algorithm


% declare global variables that will be used by other functions
global N alpha eta theta beta K omega OM L lambda A B KOM; 

% it needs to have set the parametes, for instance by running inputs.m first

% **************************************************************************************************
% Set values for inital guess of wages w0
% **************************************************************************************************

%w0 = ones(N,1);
%w0=rand(N,1);

%initial wages w0 based on the equilibrium for costless trade
for i=1: N
    w0(i,1) = ( lambda(i)/L(i) ) ^ (theta/(theta+beta));
end
%w0=linspace(1,2,N)';

% normalize intial wages:
w0 = w0 / (w0'*L);


% **************************************************************************************************
% Solve for equilibrium wages and associated quantities
% **************************************************************************************************

% calls function eqbob that solves for equilibrium wage w starting with guess w0
[w,W,distdw,distZZ] = eqT(w0);

% price of tradeable aggregate pm:
pmguess = ones(N,1); % arbitrary guess of pm
pm = price_pm(w,pmguess);                           

% non-tradeable vs tradeable relative price P:
Delta = 1 / ( alpha^alpha * (1-alpha)^(1-alpha) ) ;
Plevel = Delta * ( (w ./ pm) .^alpha ) ;         
P = Plevel/sum(Plevel) ; % normalized vector of relative prices

% consumption price p
p = Delta *  (w .^alpha) .* (pm .^(1-alpha))  ;


% Call function Z to compute objects of interest at equilibrium wages
[ZZ,D,s,F] = Z(w);


% **************************************************************************************************
% Computes statistics for the equilibrium:
% **************************************************************************************************

% Taxes = Li pmi qi sum Dij ( 1- omij )
% Taxes = beta ( Li pmi qi Fi / beta Fi ) *  sum Dij ( 1- omij )
% Taxes = Li wi (1-si) / ( beta Fi ) * sum Dij ( 1- omij )

% GDP = wiLi + Taxes; 

% Imports: Imp
% Impi = Li pmi qi ( 1- Dii)
% Impi = ( beta Li pmi qi Fi / beta Fi ) * (1-Dii)
% Impi = ( Li wi (1-si) / beta Fi ) (1-Dii)

% Volume of trade v
% vi = Impi / GDPi ;

for i=1:N
    Taxes(i,1)=0;
    for j=1:N
        Taxes(i,1) = D(i,j)*(1-OM(i,j)) + Taxes(i,1);
    end
    Taxes(i,1) =  L(i)*w(i) * (1-s(i)) * Taxes(i) / (beta*F(i)) ;
    GDP(i,1)   =  L(i)*w(i) + Taxes(i);
    Imp(i,1)   =  L(i)*w(i) * (1-s(i)) * ( 1 - D(i,i) ) / ( beta * F(i) );
end

% volume of trade = import GDP ratio v:
v = Imp ./ GDP;
% compute share of GDP in world GDP shareGDP:
shareGDP = GDP / sum(GDP);
% Taxes as Fraction of GDP
TaxesGDP = Taxes ./ GDP ;
% real consumption
c = GDP ./ ( L .* p);

% Prints some inputs of interest
disp(' ');
disp('Parameter values for some input of interest')
disp('  ')
disp(['number of countries = ', num2str(N)])
disp([' alpha = ', num2str(alpha)])
disp([' beta  = ', num2str(beta)])
disp([' theta = ', num2str(theta)])
disp([' kappa = ', num2str(kappa)])
disp([' omega = ', num2str(omega)])
disp('be warned that the matrices K and OM may have been entered manually')
disp('so the scalars omega and kappa may not discribe the tariffs and transp. costs')
disp(' ');


% **************************************************************************************************
% Produces Plots with statistics of interest
% **************************************************************************************************

figure(1)
plot(W)
title('path of relative wages')
xlabel('countries')

cc = [1:1:N];
figure(2)
plot(cc,w0,cc,w)
title('equilibrium wages vs initial wages')
xlabel('countries')

figure(3)
plot(w./sqrt(w'*L))
title('equilibrium wages')
xlabel('countries')

figure(4)
plot(ZZ./L)
title('Values of the excess demand Z at equilibrium wages')
ylabel('Excess demand as fraction of toatl labor, Z(i)/L(i) ')
xlabel('countries')

figure(5)
plot(distZZ)
title('value of the norm of the excess demand on sucessive iterations')
xlabel('iteration');

figure(6)
plot(shareGDP,v,'b*')
title('Volume of Trade vs Share of GDP in world GDP')
xlabel('Share in World GDP')
ylabel('Imports / GDP ');

figure(7)
plot(log(shareGDP),v,'b*')
title('Volume of Trade vs Share of GDP in world GDP')
xlabel('log Share in World GDP')
ylabel('Imports / GDP ');

figure(8)
plot(shareGDP,TaxesGDP,'b*')
title('Taxes vs Share of GDP in world GDP')
xlabel('Share in World GDP')
ylabel('Taxes / GDP ');

figure(9)
plot(shareGDP,w,'b*')
title('wages  vs Share of GDP in world GDP')
xlabel('Share in World GDP')
ylabel('wage w ');

figure(10)
plot(log(w0),log(w),'b*')
title('log(wages)  vs  (theta/theta+beta) * log(lambda/L)')
xlabel(' (theta/theta+beta) * log(lambda/L) ')
ylabel(' log(w) ');

figure(11)
plot(shareGDP,pm,'b*')
title('price of tradeable aggreate  vs Share of GDP in world GDP')
xlabel('Share in World GDP')
ylabel('pm ');

figure(12)
plot(shareGDP,Plevel,'b*')
title('price of non-tradeable relative to tradeable vs Share of GDP in world GDP')
xlabel('Share in World GDP')
ylabel(' pi/pmi ');
