function [philambda,phiL,phiOM] = phiLandOmega(Y,Vcal,lambdaini,Lini,OMvecini)
global N alpha eta theta beta K omega OM L lambda A B KOM; 

% phiLandOmega.m   Apirl 4, 2004
% The inputs should have lambdaini = Lini
% [philambda,phiL,phiOM] = phiLandOmega(Y,lambdaini,Lini,OMini)
% lambdaini is the initial lambda
% Lini is the inital L
% OM ini is the initial OM matrix
% vectors philambda, phiL phiOM are the iterates of lambda and L
% philambda and phiL are each in the N-dimensional simplex



% (1) Compute equilibrium for given L and lambda 
%initial wages w0 based on the equilibrium for costless trade

L = Lini;
lambda = L;
% set initial OM and KOM matrices
for i=1: N
    w0(i,1) = ( lambda(i)/L(i) ) ^ (theta/(theta+beta));
end
% normalize intial wages:
w0 = w0 / (w0'*L);
for i=1:N
    %OM(i,1:N) = 1 - .5*(tariffwb(i)+tariffwto(i))/100;
    OM(i,1:N) = OMvecini(i);
    OM(i,i) = 1;
end;
% define KOM
KOM  = (K.*OM).^(1/theta); 
% finds equilibrium price:
w = eqT(w0);
% computes equilibrium objects
[ZZ,D,s,F] = Z(w);
pmguess = ones(N,1); % arbitrary guess of pm
pm = price_pm(w,pmguess);

% (2) Compute phi for the L components

% compute epsilon, as in notes
one = ones(N,1);
epsilon = one + (one - s) .* ( one - F) ./ (beta*F)  ;

phiL = Y ./ ( w .* epsilon ) ;
phiL = phiL / sum(phiL) ;


%(3) Compute phi for the lambda components

philambda = phiL; 

% (4) computes phi for the OM component

% uses formula (7.2)  vi = (1-alpha) / [ beta ( Dii/(1-Dii) + omi ) + 1 - omi ]

% smoothing parameter

spar = 0.2 ; % weight on new itertion 0.3 seems to work best

for i=1:N
     omi = (1 + beta * ( D(i,i)/(1-D(i,i)) )  - (1-alpha)/Vcal(i) ) / (1-beta);
     phiOM(i,1) = spar* min( max(omi, 0.001), 1) + (1-spar)*OMvecini(i);
end

