function [b,RR] = REGRESS(y,X); 

% [b,RR] = REGRESS(y,X);
%
% Regress y into X, with coefficient b
% y   =   X * b   +  e
%
% Nx1    Nxn  n+1   Nx
%
% y is an N x 1 vector, X is an N x n vector and b is a n+1 vector
% RR is the R-square
% If X does not have a constant column a column of ones is added



% solve for e' * X = (y - Xb)' * X = 0
%  (Xb')X = y'X  or b'X'X = y'X  or b' =  y'X inv(X'X)
%  or b = inv(X'X) X'y
%

[N,n] = size(X);
% Look for a column with a constant
minstd=std(X(1:N,1));
for i=1:n
    minstd = min( minstd , std(X(1:N,i)) ) ;
end
if minstd > 0
    % no constant in X, so I add one
    X = [ones(N,1),X];
end

b = inv(X'*X)*(X'*y);

e = y - X*b;

RR = 1 - var(e)/var(y) ;



