% This script computes the welfare effect of tariffs for a small open eocnomy
% it uses the approximation described in the paper: the limimt when lambda1 = k Lambda -> 0
% it uses the function welfsoe.m
% written by Fernando Alvarez, Feb 28, 2006
% it produces Figure 8.1

clear all;
close all;

% set baseline parameters 
alpha = 0.75;
beta = 0.5;


thetavec = [0.1, 0.15, 0.25];          % grid fro omega values
nomegas = 300;                           % number of omega1 in grid;
om1 = linspace(0.701,0.999,nomegas);    % vector of omega1

for j=1:3;
    theta = thetavec(j);
    for i=1:nomegas;
        omega1 = om1(i);
        wgain(i,j) = welfsoe(omega1, alpha, beta, theta); 
    end
end

wgain = log(wgain)*100;  % convert welfare gains in %

tar = (1-om1)*100;  % convert omegas in tariffs in %

plot(tar,wgain(:,1),'k',tar,wgain(:,2),'r',tar,wgain(:,3),'b');
grid; 
title({'FIGURE 8.1: WELFARE EFFECTS OF TARIFF FACTOR \omega FOR A SMALL OPEN ECONOMY','Three values of \theta'})
xlabel(['TARIFF IN PERCENT: (1 - \omega) x 100'])
ylabel('WELFARE GAIN RELATIVE TO ZERO TARIFF IN PERCENT: log difference x 100')
xl = min(tar);
xh = max(tar);
yh = max(max(wgain));
yl = min(min(wgain));
text(xl+ 0.1*(xh-xl),yl+0.3*(yh-yl),'Parameters')
text(xl+ 0.1*(xh-xl),yl+0.2*(yh-yl),['\alpha =',num2str(alpha)])
text(xl+ 0.1*(xh-xl),yl+0.1*(yh-yl),['\beta =',num2str(beta)])
text(tar(210)+1, wgain(210,1) +.15, ['\theta =',num2str(thetavec(1))])
text(tar(180)+1, wgain(180,2) +.15, ['\theta =',num2str(thetavec(2))])
text(tar(110)+1, wgain(110,3) +.15, ['\theta =',num2str(thetavec(3))])