% Feb 28 2006, 2004
% This script compare wages for the two calibrations: calibration 1 and calibration 2
% parameters alpha, beta, kappa and omega are set in inputs.m
% programs calibration1.m and calibration2.m can set tariff from data
% w1 corresponds to calibration 1 to GDP and Relative Prices
% w2 corresponds to calibration 2 to GDP with lambda=L 
% this script creastes figure 9.1 and (old) figure 9.2

% set parameters
inputs

% Step 2: load the data
dataload ;

close all; % close graphs created by dataload
% set the values to be calibrated from the data

Pcal = pmachtocons .^ (-1);
Pcal = Pcal / sum(Pcal);

shareGDPcal = shareGDPdata;
shareGDPcal = shareGDPcal/sum(shareGDPcal);

% assigns omegas OM using data on tariffs
for i=1:N
%    OM(i,1:N) = 1 - .5*(tariffwto(i)+tariffwb(i))/100;
    OM(i,1:N) = 1 - tariffwto(i)/100;
    OM(i,i) = 1;
end;
KOM  = (K.*OM).^(1/theta); %


% Step 3: run the program to calibrate lambda and L: calibration 1
outputcal1;

w1 = w;
L1 = L;
lambda1 = lambda;
P1 = P;

close all;

% Step 4: run program to calibrate lambda and L: calibration 2
outputcal2;

w2 = w;
L2 = L;
lambda2 = lambda;
P2 = P;


close all;




figure(1);
plot(log(shareGDPcal),w1,'k*',log(shareGDPcal),w2,'bo')
title('FIGURE 9.1: WAGES IN THE TWO CALIBRATIONS')
xlabel('COUNTRY SIZE: log of share of GDP')
ylabel('WAGES')
grid;

ylow = min(min(w1),min(w2));
yhigh = max(max(w1),max(w2));

text(log(0.1),ylow+(yhigh-ylow)*0.4,'Parameters');
text(log(0.1),ylow+(yhigh-ylow)*0.325,['\alpha = ',num2str(alpha)]);
text(log(0.1),ylow+(yhigh-ylow)*0.25,['\beta = ',num2str(beta)]);
text(log(0.1),ylow+(yhigh-ylow)*0.175,['\kappa = ',num2str(kappa)]);
text(log(0.1),ylow+(yhigh-ylow)*0.1,['\theta = ',num2str(theta)]);

text(log(0.02),ylow+(yhigh-ylow),    ['\sigma (log w ) = ', num2str(std(log(w2)),2), ' for constant \lambda / L'] )
text(log(0.02),ylow+.9*(yhigh-ylow), ['\sigma (log w ) = ', num2str(std(log(w1)),2), ' for variable \lambda / L' ] )


figure(2)
plot(gdppercap/gdppercap(1),w1/w1(1),'k*',gdppercap/gdppercap(1),(pmachtocons/pmachtocons(1)).^-1,'bo');
title({'OLD FIGURE 9.2: MEASURED RELATIVE PRICES P AND SIMULATED WAGES','Wages: (*), and Relative Prices P: (o)' })
xlabel('Real per capita GDP PPP adjusted, normalized to US=1')
ylabel('WAGES and RELATIVE PRICES P, normalized to US=1')

grid;

ylow  = min ( min( w1/w1(1) ) , min( (pmachtocons/pmachtocons(1)).^-1 ) );
yhigh = max ( max( w1/w1(1) ) , max( (pmachtocons/pmachtocons(1)).^-1 ) );

text(0.69,ylow+(yhigh-ylow)*0.375,'Parameters for simulated wage');
text(0.7,ylow+(yhigh-ylow)*0.3,['\alpha = ',num2str(alpha)]);
text(0.7,ylow+(yhigh-ylow)*0.225,['\beta = ',num2str(beta)]);
text(0.7,ylow+(yhigh-ylow)*0.15,['\kappa = ',num2str(kappa)]);
text(0.7,ylow+(yhigh-ylow)*0.075,['\theta = ',num2str(theta)]);


r1 = corrcoef(log(gdppercap),-log(pmachtocons));
r2 = corrcoef(log(w1),-log(pmachtocons));
r3 = corrcoef(log(w1), log(gdppercap));

ylow = min( min(w1), min(w2));
yhigh = max( max(w1), max(w2));


%text(0.5, ylow + 0.2*(yhigh-ylow), ['\rho( log real gdp/pop , log P ) = ' num2str(r1(1,2),2) ]) 
%text(0.5, ylow + 0.15*(yhigh-ylow), ['\rho( log w_2  , log P ) = ' num2str(r2(1,2),2) ]) 
% text(0.5, ylow + 0.1*(yhigh-ylow), ['\rho( log w_2,  log real gdp/pop ) = ' num2str(r3(1,2),2) ]) 

%for i=1:N;
%    text(gdppercap(i), (pmachtocons(i)/pmachtocons(1))^-1, codes(i,:))
%end

figure(3)
plot(gdppercap/gdppercap(1),w1/w1(1),'k*',gdppercap/gdppercap(1),lambda1./L1/(lambda1(1)/L1(1)),'bo',gdppercap/gdppercap(1),(pmachtocons/pmachtocons(1)).^-1,'r+');
title({'WAGES (*), CALIBRATED \lambda/L (o), RELATIVE PRICES P (.) ' , 'P = price consumption / price machinery and equip. (+)' })
xlabel('Real per capita GDP, PPP adjusted')
ylabel('wages w, and P, normalized so that US=1, \lambda/L measure in scale at the right')

grid;

axis( [0, 1, 0, 2,] )

r1 = corrcoef(log(gdppercap),-log(pmachtocons));
r2 = corrcoef(log(w),-log(pmachtocons));
r3 = corrcoef(log(w), log(gdppercap));
r4 = corrcoef(log(w), log(lambda1./L1));

ylow = min( min(w1), min(w2));
yhigh = max( max(w1), max(w2));

text(0.5, ylow + 0.2*(yhigh-ylow), ['\rho( log real gdp/pop , log P ) = ' num2str(r1(1,2),2) ]) 
text(0.5, ylow + 0.15*(yhigh-ylow), ['\rho( log w1  , log P ) = ' num2str(r2(1,2),2) ]) 
text(0.5, ylow + 0.1*(yhigh-ylow), ['\rho( log w1,  log real gdp/pop ) = ' num2str(r3(1,2),2) ]) 
text(0.5, ylow + 0.05*(yhigh-ylow), ['\rho( log w1,  log \lambda/L ) = ' num2str(r4(1,2),2) ]) 

%for i=1:N;
%    text(gdppercap(i), (pmachtocons(i)/pmachtocons(1))^-1, codes(i,:))
%end

figure(4)
plot(gdppercap/gdppercap(1),w1/w1(1),'k*',gdppercap/gdppercap(1),lambda1./L1/(lambda1(1)/L1(1)),'bo',gdppercap/gdppercap(1),(pmachtocons/pmachtocons(1)).^-1,'r.');
title({'WAGES (*), CALIBRATED \lambda/L (o), RELATIVE PRICES P (.) ' , 'P = price consumption / price machinery and equip. (.)' })
xlabel('Real per capita GDP, PPP adjusted')
ylabel('wages w, and P, normalized so that US=1, \lambda/L measure in scale at the right')

grid;

axis( [0, 1, 0, 2,] )

r1 = corrcoef(log(gdppercap),-log(pmachtocons));
r2 = corrcoef(log(w),-log(pmachtocons));
r3 = corrcoef(log(w), log(gdppercap));
r4 = corrcoef(log(w), log(lambda1./L1));

ylow = min( min(w1), min(w2));
yhigh = max( max(w1), max(w2));

text(0.5, ylow + 0.2*(yhigh-ylow), ['\rho( log real gdp/pop , log P ) = ' num2str(r1(1,2),2) ]) 
text(0.5, ylow + 0.15*(yhigh-ylow), ['\rho( log w1  , log P ) = ' num2str(r2(1,2),2) ]) 
text(0.5, ylow + 0.1*(yhigh-ylow), ['\rho( log w1,  log real gdp/pop ) = ' num2str(r3(1,2),2) ]) 
text(0.5, ylow + 0.05*(yhigh-ylow), ['\rho( log w1,  log \lambda/L ) = ' num2str(r4(1,2),2) ]) 

for i=1:N;
    text(gdppercap(i), (pmachtocons(i)/pmachtocons(1))^-1, codes(i,:))
end

figure(5)
plot(gdppercap/gdppercap(1),log(w1/w1(1)),'k*',gdppercap/gdppercap(1),log( (lambda1./L1) / ( lambda1(1)/L1(1) ) ),'bo',gdppercap/gdppercap(1),log((pmachtocons/pmachtocons(1)).^-1),'r.');
title({'WAGES (*), CALIBRATED \lambda/L (o), RELATIVE PRICES P (.) ' , 'P = price consumption / price machinery and equip. (.)' })
xlabel('Real per capita GDP, PPP adjusted')
ylabel('wages w, P, and \lambda/L  normalized so that US=1, in logs')

grid;

axis( [0, 1, log(0.01), log(6)] )

r1 = corrcoef(log(gdppercap),-log(pmachtocons));
r2 = corrcoef(log(w),-log(pmachtocons));
r3 = corrcoef(log(w), log(gdppercap));
r4 = corrcoef(log(w), log(lambda1./L1));

ylow = min( log(min(w1)), log(min(w2)));
yhigh = max( log(max(w1)), log(max(w2)));

text(0.5, ylow + 0.25*(yhigh-ylow), ['\rho( log real gdp/pop , log P ) = ' num2str(r1(1,2),2) ]) 
text(0.5, ylow + 0.125*(yhigh-ylow), ['\rho( log w1  , log P ) = ' num2str(r2(1,2),2) ]) 
text(0.5, ylow + 0.725*(yhigh-ylow), ['\rho( log w1,  log real gdp/pop ) = ' num2str(r3(1,2),2) ]) 
text(0.5, ylow + 0.025*(yhigh-ylow), ['\rho( log w1,  log \lambda/L ) = ' num2str(r4(1,2),2) ]) 

for i=1:N;
    text(gdppercap(i), log((pmachtocons(i)/pmachtocons(1))^-1), codes(i,:))
end

figure(6)
plot(gdppercap/gdppercap(1),log(w1/w1(1)),'k*',gdppercap/gdppercap(1),log( (lambda1./L1) / ( lambda(1)/L1(1) ) ),'bo',gdppercap/gdppercap(1),log((pmachtocons/pmachtocons(1)).^-1),'r+');
title({'FIGURE 10.1: WAGES (*), CALIBRATED \lambda/L (o), RELATIVE PRICES P (.) ' , 'P = price consumption / price machinery and equip. (+)' })
xlabel('Real per capita GDP, PPP adjusted')
ylabel('wages w, P, and \lambda/L  normalized so that US=1, in logs')

grid;

axis( [0, 1, log(0.01), log(6)] )

r1 = corrcoef(log(gdppercap),-log(pmachtocons));
r2 = corrcoef(log(w),-log(pmachtocons));
r3 = corrcoef(log(w), log(gdppercap));
r4 = corrcoef(log(w), log(lambda1./L1));

ylow = min( log(min(w1)), log(min(w2)));
yhigh = max( log(max(w1)), log(max(w2)));

text(0.5, ylow + 0.25*(yhigh-ylow), ['\rho( log real gdp/pop , log P ) = ' num2str(r1(1,2),2) ]) 
text(0.5, ylow + 0.175*(yhigh-ylow), ['\rho( log w1  , log P ) = ' num2str(r2(1,2),2) ]) 
text(0.5, ylow + 0.1*(yhigh-ylow), ['\rho( log w1,  log real gdp/pop ) = ' num2str(r3(1,2),2) ]) 
text(0.5, ylow + 0.0251*(yhigh-ylow), ['\rho( log w1,  log \lambda/L ) = ' num2str(r4(1,2),2) ]) 



