% This script uses the two country version of the model to analyze the welfare
% of tariffs.
% Written by Constantino Hevia, May 1, 2004
% This program uses the function welfsoe.m


clear all;
close all;
%================================================
% SET PARAMETER VALUES
%================================================

kappa1	=	0.75;					% kappa12=transportation cost from 2 to 1
kappa2	=	0.75;					% kappa21=transportation cost from 1 to 2
om2		=	1;					    %(1-omega21)= tariff levied by contry 2 on goods imported from country 1
kk			=  1;

L1			=  [0.01, 0.1, 0.3] ;       				%Choose L1 to lie in (0,1)
L2			=  1-L1;									%Work under the assumption L1+L2=1
lambda1	=	kk*L1;				
lambda2	=	kk*L2;		

alpha		=	0.75;				%Labor parameter in final goods
beta		=  0.5;				%Labor parameter in tradeables

eta 		= 	1.5;				%Elasticity of substitution

thetavec = [0.1, 0.15, 0.25];				%Dispersion parameter

nomegas = 50;									% size grid for omega1
om1 = linspace(0.701,0.999,nomegas);   % vector of omega1

grid_m			=  round(nomegas/2);
grid_q			=	round(nomegas/4);

disp( '   ');
disp( 'Parameters:' );
disp( '==========');
disp([' theta = [', num2str(thetavec),']'])
disp([' beta  = [', num2str(beta),']'])
disp([' alpha = ', num2str(alpha)])
disp([' eta   = ', num2str(eta)])
disp('   ');
disp('-----------------------------------------------')


% =========================
% INTERMEDIATE CALCULATIONS
% =========================
% Compute B for a bunch of betas

B = beta^(-beta)*(1-beta)^(beta-1);

% Compute capital delta

DELTA	= alpha^(-alpha)*(1-alpha)^(alpha-1);

% Compute A for a bunch of thetas

A=zeros(length(thetavec),1);
for j=1:length(thetavec)
   if 1+thetavec(j)*(1-eta)<=0					%Check if 1+theta*(1-eta)>0
      error('1+theta*(1-eta) is negative. Change the parameters.')
   end      
   A(j) = ( gamma(1+thetavec(j)*(1-eta)) )^(1/(1-eta)) ;
end

% ====================================================================================
% INITIALIZE THE VARIABLES WHERE WE WILL STORE THE EQUILIBRIUM PRICES, QUANTITIES, ETC
% ====================================================================================
 
c1		 = zeros(nomegas,length(thetavec),length(L1));		%To store consumption in 2 country case
wgain2 = zeros(nomegas,length(thetavec),length(L1));		%To store 2 country welfare results
wgain  = zeros(nomegas,length(thetavec)); 	 				%To store soe welfare results



%================================================
% COMPUTATION OF THE EQUILIBRIUM
%================================================
for j=1:length(thetavec)
   for k=1:nomegas 
      for i=1:length(L1)

      	
   		% USE BISECTION ON WAGES TO FIND THE EQUILIBRIUM.
   		% Given homogeneity property, set w2=1 and solve for w1.
   
   		w1a=0.1;		%Set initial range for w1
      	w1b=10;
         
      	%Find Excess demand for w1a
   		prm	= pm(w1a,1,A(j),B,lambda1(i),lambda2(i),beta,thetavec(j),kappa1,om1(k),kappa2,om2);
      	D11	= lambda1(i)*[ (prm(1)/w1a)^beta/(A(j)*B) ]^(1/thetavec(j));
   		D12	= 1-D11;
   		D22	= lambda2(i)*[ prm(2)^beta/(A(j)*B) ]^(1/thetavec(j));
			D21	= 1-D22;
   		F1		= D11+D12*om1(k);
   		F2		= D21*om2+D22;
   		s1		= 1 - (1-alpha)*beta*F1/[alpha + (beta-alpha)*F1];
      	s2		= 1 - (1-alpha)*beta*F2/[alpha + (beta-alpha)*F2];
      	Z1a	=  L1(i)*w1a*(1-s1)*D11/F1 + L2(i)*(1-s2)*D21*om2/F2 - L1(i)*w1a*(1-s1);
         
      	% Find Excess demand for w1b
   		prm	= pm(w1b,1,A(j),B,lambda1(i),lambda2(i),beta,thetavec(j),kappa1,om1(k),kappa2,om2);
      	D11	= lambda1(i)*[ (prm(1)/w1b)^beta/(A(j)*B) ]^(1/thetavec(j));
   		D12	= 1-D11;
   		D22	= lambda2(i)*[ prm(2)^beta/(A(j)*B) ]^(1/thetavec(j));
			D21	= 1-D22;
   		F1		= D11+D12*om1(k);
   		F2		= D21*om2+D22;
   		s1		= 1 - ((1-alpha)*beta*F1)/[alpha + (beta-alpha)*F1];
   		s2		= 1 - ((1-alpha)*beta*F2)/[alpha + (beta-alpha)*F2];         
      	Z1b	=  L1(i)*w1b*(1-s1)*D11/F1 + L2(i)*(1-s2)*D21*om2/F2 - L1(i)*w1b*(1-s1);
         
      	if Z1a*Z1b>0
         	disp(['Z1a =',num2str(Z1a)])	
         	disp(['Z1b =',num2str(Z1b)])
         	error('Zero not bracketed in bisection for wage rate. Expand the range of transformed wages')
      	end

      	dist=1;
      	iter=0;
      	while dist>1E-12			%MAIN BISECTION ALGORITHM     
         	iter=iter+1;
         	% COMPUTE EXCESS DEMAND AT MIDPOINT ww1m
         	w1m	= 0.5*(w1a+w1b);
   			prm	= pm(w1m,1,A(j),B,lambda1(i),lambda2(i),beta,thetavec(j),kappa1,om1(k),kappa2,om2);
         	D11	= lambda1(i) * [ ((prm(1)/w1m)^beta)/(A(j)*B) ]^(1/thetavec(j));
   			D12	= 1-D11;
   			D22	= lambda2(i) * [ (prm(2)^beta)/(A(j)*B) ]^(1/thetavec(j));
				D21	= 1-D22;
   			F1		= D11 + D12 * om1(k);
   			F2		= D21 * om2 + D22;
   			s1		= 1 - (1-alpha)*beta*F1/[alpha + (beta-alpha)*F1];
   			s2		= 1 - (1-alpha)*beta*F2/[alpha + (beta-alpha)*F2];        
  				Z1m	=  L1(i)*w1m*(1-s1)*D11/F1 + L2(i)*(1-s2)*D21*om2/F2 - L1(i)*w1m*(1-s1);
        
         	if Z1a*Z1m<0			%i.e. if zero is between ww1a and ww1m
            	w1b	= w1m;
            	Z1b  = Z1m;
         	elseif Z1a*Z1m>0
            	w1a	= w1m;
            	Z1a  = Z1m;
         	else
            	break
         	end
        		dist	= abs(w1b-w1a);    
      	end

      	p1	= DELTA * w1m^alpha * prm(1)^(1-alpha);
      	c1(k,j,i) 	= w1m*[1+(1-s1)*D12*(1-om1(k))/(beta*F1)]/p1;      
         
      end
   end
end

%Compute the welfare gains using the small open economy equations

for j=1:length(thetavec);
    theta = thetavec(j);
    for i=1:nomegas;
        omega1 = om1(i);
        wgain(i,j) = welfsoe(omega1, alpha, beta, theta); 
    end
end


%Compute welfare gains using the two country code
for j=1:length(thetavec)			
   for k=1:nomegas
      for i=1:length(L1)
         wgain2(k,j,i) = c1(k,j,i)/c1(end,j,i); 
      end
   end
end


tar = (1-om1)*100; 		 	% convert omegas in tariffs in %
wgain = log(wgain)*100;  	% convert welfare gains in %
wgain2 = log(wgain2)*100;  % convert welfare gains in %


figure
plot(tar,wgain(:,1),'k',tar,wgain2(:,1,1),'r',tar,wgain2(:,1,2),'b',tar,wgain2(:,1,3),'g');
grid; 
title({'WELFARE EFFECTS OF A TARIFF FACTOR \omega FOR A SMALL OPEN ECONOMY', [' AND FOR THE TWO COUNTRY MODEL. ','\theta = ' num2str(thetavec(1))]})
xlabel(['TARIFF IN PERCENT: (1 - \omega) x 100'])
ylabel('WELFARE GAIN RELATIVE TO ZERO TARIFF IN PERCENT: log difference x 100')
xl = min(tar);
xh = max(tar);
yh = max(max(max(wgain)),max(max(wgain2(:,1,:))));
yl = min(min(min(wgain)),min(min(wgain2(:,1,:))));
text(xl+ 0.1*(xh-xl),yl+0.25*(yh-yl),'Parameters')
text(xl+ 0.1*(xh-xl),yl+0.2*(yh-yl),['\alpha =',num2str(alpha)])
text(xl+ 0.1*(xh-xl),yl+0.15*(yh-yl),['\beta =',num2str(beta)])
text(xl+ 0.1*(xh-xl),yl+0.1*(yh-yl),['\theta =',num2str(thetavec(1))])
legend('small open economy',['L1 = ', num2str(L1(1))],['L2 = ', num2str(L1(2))],['L1 = ', num2str(L1(3))])

figure
plot(tar,wgain(:,2),'k',tar,wgain2(:,2,1),'r',tar,wgain2(:,2,2),'b',tar,wgain2(:,2,3),'g');
grid; 
title({'WELFARE EFFECTS OF A TARIFF FACTOR \omega FOR A SMALL OPEN ECONOMY', [' AND FOR THE TWO COUNTRY MODEL. ','\theta = ' num2str(thetavec(2))]})
xlabel(['TARIFF IN PERCENT: (1 - \omega) x 100'])
ylabel('WELFARE GAIN RELATIVE TO ZERO TARIFF IN PERCENT: log difference x 100')
xl = min(tar);
xh = max(tar);
yh = max(max(max(wgain)),max(max(wgain2(:,2,:))));
yl = min(min(min(wgain)),min(min(wgain2(:,2,:))));
text(xl+ 0.1*(xh-xl),yl+0.25*(yh-yl),'Parameters')
text(xl+ 0.1*(xh-xl),yl+0.2*(yh-yl),['\alpha =',num2str(alpha)])
text(xl+ 0.1*(xh-xl),yl+0.15*(yh-yl),['\beta =',num2str(beta)])
text(xl+ 0.1*(xh-xl),yl+0.1*(yh-yl),['\theta =',num2str(thetavec(2))])

legend('small open economy',['L1 = ', num2str(L1(1))],['L2 = ', num2str(L1(2))],['L1 = ', num2str(L1(3))])

figure
plot(tar,wgain(:,1),'k',tar,wgain2(:,1,1),'r',tar,wgain2(:,1,2),'b',tar,wgain2(:,1,3),'g');
grid; 
title({'WELFARE EFFECTS OF A TARIFF FACTOR \omega FOR A SMALL OPEN ECONOMY', [' AND FOR THE TWO COUNTRY MODEL. ','\theta = ' num2str(thetavec(3))]})
xlabel(['TARIFF IN PERCENT: (1 - \omega) x 100'])
ylabel('WELFARE GAIN RELATIVE TO ZERO TARIFF IN PERCENT: log difference x 100')
xl = min(tar);
xh = max(tar);
yh = max(max(max(wgain)),max(max(wgain2(:,3,:))));
yl = min(min(min(wgain)),min(min(wgain2(:,3,:))));
text(xl+ 0.1*(xh-xl),yl+0.25*(yh-yl),'Parameters')
text(xl+ 0.1*(xh-xl),yl+0.2*(yh-yl),['\alpha =',num2str(alpha)])
text(xl+ 0.1*(xh-xl),yl+0.15*(yh-yl),['\beta =',num2str(beta)])
text(xl+ 0.1*(xh-xl),yl+0.1*(yh-yl),['\theta =',num2str(thetavec(3))])
legend('small open economy',['L1 = ', num2str(L1(1))],['L2 = ', num2str(L1(2))],['L1 = ', num2str(L1(3))])