% Welfare Gains 1, March 25 2004
% This file computes the welfare change of two economies tar (for tariffs) and ft (for free trade).
% The economy with tarirffs is calibrated to GDP and Relative Price distribution shareGDPcal, Pcal  from the data.
% The economies are identical in all parameters except that on tariffs OM.
% The ft economy has tariffs equal to the US economy
% It needs to have all parameters assigned, -for instance by runing imputs.m
% It uses the script outputeq.m and the functions used there.


clear all;

% Step 1: set the inputs
inputs ;        

% Step 2: load the data
dataload ;

close all; % close graphs created by dataload

shareGDPcal = shareGDPdata;
shareGDPcal = shareGDPcal/sum(shareGDPcal);
Pcal = pmachtocons .^ (-1);
Pcal = Pcal / sum(Pcal);


% assigns omegas OM using dagta on tariffs
for i=1:N
%    OM(i,1:N) = 1 - .5*(tariffwto(i)+tariffwb(i))/100;
    OM(i,1:N) = 1 - tariffwto(i)/100;
    OM(i,i) = 1;
end;
KOM  = (K.*OM).^(1/theta); %


% Step 3: run the program to calibrate L and lambda to GDP and relative prices:
outputcal1;

ctar = c;  % consumption per effective unit of labor
Ltar = L;  
pmtar = pm;
Ptar = P;  % relative prices 
wtar = w;
Taxtar = Taxes;
GDPtar = GDP;

% Go to US tariffs
UStariff = 1 - (.5*(tariffwto(1)+tariffwb(1))/100);
%omega=UStariff;
omega=1;
OM = (1-omega)*eye(N) + omega*ones(N,N);
KOM  = (K.*OM).^(1/theta); %

% run the program to calibrate lambda = L:
outputeq;
cft = c;
Lft = L;
pmft = pm;
Pft = P;
wft = w;
Taxft = Taxes;
GDPft = GDP;

% welfare gain, in %
wgain = log(cft./ctar)*100;

close all;

figure(1);
plot(tariffwto,wgain,'b*');
title({['welfare gains of reducing tariffs to omega = ',num2str(omega), ', in %'],'L and lambda calibrated to GDP and Relative prices'});
xlabel('tariffs before reduction, in %')
ylabel('welfare gains in %');
grid;
xl = min(tariffwto);
xh = max(tariffwto);
yh = max(log(cft./ctar)*100);
yl = min(log(cft./ctar)*100);
text(xl+0.85*(xh-xl),yl+0.9*(yh-yl),'Parameters');
text(xl+0.85*(xh-xl),yl+0.85*(yh-yl),['\alpha = ',num2str(alpha)]);
text(xl+0.85*(xh-xl),yl+0.8*(yh-yl),['\beta = ',num2str(beta)]);
text(xl+0.85*(xh-xl),yl+0.75*(yh-yl),['\theta = ',num2str(theta)]);
text(xl+0.85*(xh-xl),yl+0.7*(yh-yl),['\kappa = ',num2str(kappa)]);

figure(2);
plot(log(shareGDP),wgain,'b*');
title({['welfare gains of reducing tariffs to omega = ',num2str(omega), ' in %'],'L and lambda calibrated to GDP and Relative prices'});
xlabel('Log of Share of GDP')
ylabel('welfare gains, in %');
grid;
xl = min(log(shareGDP));
xh = max(log(shareGDP));
yh = max(log(cft./ctar)*100);
yl = min(log(cft./ctar)*100);
text(xl+0.85*(xh-xl),yl+0.9*(yh-yl),'Parameters');
text(xl+0.85*(xh-xl),yl+0.85*(yh-yl),['\alpha = ',num2str(alpha)]);
text(xl+0.85*(xh-xl),yl+0.8*(yh-yl),['\beta = ',num2str(beta)]);
text(xl+0.85*(xh-xl),yl+0.75*(yh-yl),['\theta = ',num2str(theta)]);
text(xl+0.85*(xh-xl),yl+0.7*(yh-yl),['\kappa = ',num2str(kappa)]);
