% March 25 2004
% This file computes the welfare change of two economies tar (for tariffs) and ft (for free trade).
% The economy with tarirffs is calibrated to GDP distribution shareGDPcal from the data and L=lambda.
% The economies are identical in all parameters except that on tariffs OM.
% The ft economy has tariffs equal to the US economy
% It needs to have all parameters assigned, -for instance by runing imputs.m
% It uses the script outputeq.m and the functions used there.
% This file produces Figure 9.2b
% which takes into account the trade unions


clear all;

% Step 1: set the inputs
inputs ;        

% Step 2: load the data
dataload ;

a=1; clear a;

close all; % close graphs created by dataload

shareGDPcal = shareGDPdata;
shareGDPcal = shareGDPcal/sum(shareGDPcal);


% assigns omegas OM using dagta on tariffs
    % loads block a matrix with 1 for the countries in a trade union
    blockmatrix ;
    OM = block;
    % assigns values to matrix OM of tariffs using data
    for i=1:N
        %OM(i,1:N) = 1 - .5*(tariffwb(i)+tariffwto(i))/100;
        for j=1:N
            if OM(i,j) == 0;
                OM(i,j) = 1 - tariffwto(i)/100;
            end
        end
        OM(i,i) = 1;
    end;

    KOM  = (K.*OM).^(1/theta); %


% Step 3: run the program to calibrate lambda = L to GDP:
outputcal2;

ctar = c;
Ltar = L;
pmtar = pm;
Ptar = P;
wtar = w;
Taxtar = Taxes;
GDPtar = GDP;

% Go to US tariffs
UStariff = 1 - tariffwto/100;
%omega=UStariff;
omega = 1;
OM = (1-omega)*eye(N) + omega*ones(N,N);
KOM  = (K.*OM).^(1/theta); %

% run the program to calibrate lambda = L:
outputeq;
cft = c;
Lft = L;
pmft = pm;
Pft = P;
wft = w;
Taxft = Taxes;
GDPft = GDP;

% welfare gain, in %
wgain = log(cft./ctar)*100;

a=1; clear a;

close all;

aa=1;
clear aa;

figure(1);
plot(tariffwto,wgain,'b*');
title({['FIGURE 9.2: WELFARE GAINS FROM ELIMINATING TARIFFS']});
xlabel('TARIFFS BEFORE REDUCTION IN PERCENT: (1 - \Omega_i) x 100 ')
ylabel('WELFARE GAIN IN PERCENT: log difference x 100');
grid;
xl = min(tariffwto);
xh = max(tariffwto);
yh = max(log(cft./ctar)*100);
yl = min(log(cft./ctar)*100);
text(xl+0.1*(xh-xl),yl+0.9*(yh-yl),'Parameters');
text(xl+0.1*(xh-xl),yl+0.825*(yh-yl),['\alpha = ',num2str(alpha)]);
text(xl+0.1*(xh-xl),yl+0.75*(yh-yl),['\beta = ',num2str(beta)]);
text(xl+0.1*(xh-xl),yl+0.675*(yh-yl),['\kappa = ',num2str(kappa)]);
text(xl+0.1*(xh-xl),yl+0.6*(yh-yl),['\theta = ',num2str(theta)]);

i = 1;
text(tariffwto(i)+0.5,wgain(i)-0.02,'USA')
i = 2;
text(tariffwto(i)+0.5,wgain(i)+0.04,'Japan')
i = 17;
text(tariffwto(i)+0.5,wgain(i)+0.02,'Argentina')
i = 46 ;
text(tariffwto(i)+0.3,wgain(i)+0.02,'Peru')
i= 47 ;
text(tariffwto(i)+0.5,wgain(i)+0.02,'Czech Republic')
i = 51;
text(tariffwto(i)+0.5,wgain(i)+0.02,'Bangladesh')
i = 9;
text(tariffwto(i)+0.5,wgain(i)+0.02,'Brazil')
i = 54;
text(tariffwto(i)+0.5,wgain(i)+0.02,'Nigeria')
i = 44;
text(tariffwto(i)-4,wgain(i)+0.06,'Pakistan')
i= 25 ;
text(tariffwto(i)+0.5,wgain(i)+0.04,'Hong Kong')
i= 13 ;
text(tariffwto(i)+0.5,wgain(i)+0.02,'India')
i= 5 ;
text(tariffwto(i)+0.5,wgain(i)+0.02,'France')



figure(2);
plot(log(shareGDP),wgain,'b*');
title({['FIGURE 92B: WELFARE GAINS OF ELIMINATING TARIFFS']});
xlabel('SIZE: Log of GDP Share')
ylabel('WELFARE GAIN IN PERCENT: log difference x 100');
grid;
xl = min(log(shareGDP));
xh = max(log(shareGDP));
yh = max(log(cft./ctar)*100);
yl = min(log(cft./ctar)*100);
text(xl+0.85*(xh-xl),yl+0.9*(yh-yl),'Parameters');
text(xl+0.85*(xh-xl),yl+0.825*(yh-yl),['\alpha = ',num2str(alpha)]);
text(xl+0.85*(xh-xl),yl+0.75*(yh-yl),['\beta = ',num2str(beta)]);
text(xl+0.85*(xh-xl),yl+0.675*(yh-yl),['\theta = ',num2str(theta)]);
text(xl+0.85*(xh-xl),yl+0.6*(yh-yl),['\kappa = ',num2str(kappa)]);

i = 1;
text(log(shareGDP(i))+0.05,wgain(i)-0.02,'USA')
i = 2;
text(log(shareGDP(i))+0.05,wgain(i)+0.04,'Japan')
i = 17;
text(log(shareGDP(i))+0.05,wgain(i)+0.04,'Argentina')
i = 46 ;
text(log(shareGDP(i))+0.02,wgain(i)+0.02,'Peru')
%i= 47 ;
%text(log(shareGDP(i))+0.1,wgain(i)+0.02,'Czech Republic')
i = 51;
text(log(shareGDP(i))+0.05,wgain(i)+0.04,'Bangl.')
i = 9;
text(log(shareGDP(i))+0.05,wgain(i),'Brazil')
i = 54;
text(log(shareGDP(i))+0.05,wgain(i),'Nigeria')
i = 44;
text(log(shareGDP(i))+0.05,wgain(i)+0.06,'Pakistan')
i= 25 ;
text(log(shareGDP(i))+0.05,wgain(i)+0.04,'Hong Kong')
i= 13 ;
text(log(shareGDP(i))+0.05,wgain(i)+0.02,'India')
i= 5 ;
text(log(shareGDP(i))+0.05,wgain(i)+0.02,'France')


